@@ -114,9 +114,6 @@ struct audio_feed *audio_feed_init(struct threads_info *ti)
    self->input_port[0] = jack_port_register(self->jack_h, "lt_in", JACK_DEFAULT_AUDIO_TYPE, JackPortIsInput, 0);
    self->input_port[1] = jack_port_register(self->jack_h, "rt_in", JACK_DEFAULT_AUDIO_TYPE, JackPortIsInput, 0);
    
-   self->output_port[0] = jack_port_register(self->jack_h, "lt_out", JACK_DEFAULT_AUDIO_TYPE, JackPortIsOutput, 0);
-   self->output_port[1] = jack_port_register(self->jack_h, "rt_out", JACK_DEFAULT_AUDIO_TYPE, JackPortIsOutput, 0);
-   
    self->sample_rate = jack_get_sample_rate(self->jack_h);
    if(jack_activate (self->jack_h))
       {
