@@ -25,8 +25,6 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <pthread.h>
-#include <ffmpeg/avcodec.h>
-#include <ffmpeg/avformat.h>
 #include "xlplayer.h"
 #include "avcodecdecode.h"
 
@@ -71,7 +69,20 @@ static void avcodecdecode_init(struct xlplayer *xlplayer)
    int src_error;
    
    if (xlplayer->seek_s)
+      {
       av_seek_frame(self->ic, -1, (int64_t)xlplayer->seek_s * AV_TIME_BASE, 0);
+      switch (self->c->codec_id)
+         {
+         case CODEC_ID_MUSEPACK7:   /* add formats here that glitch when seeked */
+#ifdef CODEC_ID_MUSEPACK8
+         case CODEC_ID_MUSEPACK8:
+#endif /* CODEC_ID_MUSEPACK8 */
+            self->drop = 1.6;
+            fprintf(stderr, "dropping %0.2f seconds of audio\n", self->drop);
+         default:
+            break;
+         }
+      }
    if ((self->resample = (self->c->sample_rate != xlplayer->samplerate)))
       {
       fprintf(stderr, "configuring resampler\n");
@@ -135,7 +146,7 @@ static void avcodecdecode_play(struct xlplayer *xlplayer)
       return;
       }
    
-   while(size > 0)
+   while(size > 0 && xlplayer->command != CMD_EJECT)
       {
       out_size = AVCODEC_MAX_AUDIO_FRAME_SIZE;
       pthread_mutex_lock(&mutex);
@@ -146,14 +157,14 @@ static void avcodecdecode_play(struct xlplayer *xlplayer)
 #endif
       pthread_mutex_unlock(&mutex);
       frames = (out_size >> 1) / channels;
-      
+
       if (len < 0)
          break;
       if (out_size <= 0)
          continue;
 
       xlplayer_make_audio_to_float(xlplayer, self->floatsamples, self->outbuf, frames, 16, channels); 
-
+      
       if (self->resample)
          {
          src_data->input_frames = frames;
@@ -163,14 +174,19 @@ static void avcodecdecode_play(struct xlplayer *xlplayer)
             xlplayer->playmode = PM_EJECTING;
             return;
             }
-         xlplayer_demux_channel_data(xlplayer, src_data->data_out, src_data->output_frames_gen, channels, 1.f);
+         xlplayer_demux_channel_data(xlplayer, src_data->data_out, frames = src_data->output_frames_gen, channels, 1.f);
          }
       else
          xlplayer_demux_channel_data(xlplayer, self->floatsamples, frames, channels, 1.f);
       
-      do {
-         xlplayer_write_channel_data(xlplayer);
-         } while(xlplayer->write_deferred && xlplayer->playmode == PM_PLAYING);
+      if (self->drop > 0)
+         self->drop -= frames / (float)xlplayer->samplerate;
+      else
+         {
+         do {
+            xlplayer_write_channel_data(xlplayer);
+            } while(xlplayer->write_deferred && xlplayer->command != CMD_EJECT);
+         }
 
       size -= len;
       inbuf_ptr += len;
@@ -184,7 +200,7 @@ int avcodecdecode_reg(struct xlplayer *xlplayer)
    struct avcodecdecode_vars *self;
    
    pthread_once(&once_control, once_init);
-   if (!(xlplayer->dec_data = self = malloc(sizeof (struct avcodecdecode_vars))))
+   if (!(xlplayer->dec_data = self = calloc(1, sizeof (struct avcodecdecode_vars))))
       {
       fprintf(stderr, "avcodecdecode_reg: malloc failure\n");
       return REJECTED;
