@@ -22,8 +22,21 @@
 #ifdef HAVE_AVCODEC
 #ifdef HAVE_AVFORMAT
 
+#ifdef HAVE_LIBAVCODEC_AVCODEC_H
+#include <libavcodec/avcodec.h>
+#else
+#ifdef HAVE_FFMPEG_AVCODEC_H
 #include <ffmpeg/avcodec.h>
+#endif /* FFMPEG_AVCODEC_H */
+#endif /* LIBAVCODEC_AVCODEC_H */
+#ifdef HAVE_LIBAVFORMAT_AVFORMAT_H
+#include <libavformat/avformat.h>
+#else
+#ifdef HAVE_FFMPEG_AVFORMAT_H
 #include <ffmpeg/avformat.h>
+#endif /* FFMPEG_AVFORMAT_H */
+#endif /* LIBAVFORMAT_AVFORMAT_H */
+
 #include "xlplayer.h"
 
 struct avcodecdecode_vars
@@ -36,6 +49,7 @@ struct avcodecdecode_vars
    int stream;
    uint8_t *outbuf;
    float *floatsamples;
+   float drop;
    };
 
 int avcodecdecode_reg(struct xlplayer *xlplayer);
