@@ -18,8 +18,6 @@
 */
 
 #include <jack/jack.h>
-#include "dsp.h"
-#include "rms_calc.h"
 
 typedef jack_default_audio_sample_t compaudio_t;
 
@@ -38,8 +36,6 @@ struct compressor
    int ducking_hold_count;
    compaudio_t ducking_db;
    compaudio_t de_ess_db;
-   struct digital_filter *filter;
-   struct rms_calc *rms_filter;
    };
 
 struct normalizer
