@@ -50,6 +50,9 @@ struct encoder_vars
    char *bit_rate_min;
    char *bit_rate_max;
    char *bit_width;
+   char *speex_mode;
+   char *speex_quality;
+   char *speex_complexity;
    char *stereo;
    char *encode_quality;
    char *use_metadata;
@@ -150,6 +153,7 @@ struct encoder
    };
 
 struct encoder *encoder_init(struct threads_info *ti, int numeric_id);
+int encoder_init_lame(struct threads_info *ti, struct universal_vars *uv, void *param);
 void encoder_destroy(struct encoder *self);
 struct encoder_op_packet *encoder_client_get_packet(struct encoder_op *op);
 void encoder_client_free_packet(struct encoder_op_packet *packet);
