@@ -32,7 +32,7 @@
 #define ACCEPTED 1
 #define REJECTED 0
 
-static void make_flac_audio_to_float(struct xlplayer *self, float *flbuf, const FLAC__int32 * const inputbuffer[], unsigned int numsamples, unsigned int bits_per_sample, unsigned int numchannels)
+void make_flac_audio_to_float(struct xlplayer *self, float *flbuf, const FLAC__int32 * const inputbuffer[], unsigned int numsamples, unsigned int bits_per_sample, unsigned int numchannels)
    {
    int sample, channel, shiftvalue = 32 - bits_per_sample;
    const float half_randmax = (float)(RAND_MAX >> 1);
@@ -94,7 +94,7 @@ static FLAC__StreamDecoderWriteStatus flac_writer_callback(const FLAC__StreamDec
             xlplayer->playmode = PM_EJECTING;
             return FLAC__STREAM_DECODER_WRITE_STATUS_ABORT;
             }
-         xlplayer_demux_channel_data(xlplayer, src_data->data_out, src_data->output_frames_gen, frame->header.channels);
+         xlplayer_demux_channel_data(xlplayer, src_data->data_out, src_data->output_frames_gen, frame->header.channels, 1.f);
          }
       else
          {
@@ -105,7 +105,7 @@ static FLAC__StreamDecoderWriteStatus flac_writer_callback(const FLAC__StreamDec
             return FLAC__STREAM_DECODER_WRITE_STATUS_ABORT;
             }
          make_flac_audio_to_float(xlplayer, self->flbuf, inputbuffer, frame->header.blocksize, frame->header.bits_per_sample, frame->header.channels);
-         xlplayer_demux_channel_data(xlplayer, self->flbuf, frame->header.blocksize, frame->header.channels);
+         xlplayer_demux_channel_data(xlplayer, self->flbuf, frame->header.blocksize, frame->header.channels, 1.f);
          }
       xlplayer_write_channel_data(xlplayer);
       }
