@@ -18,13 +18,16 @@
 */
 
 #include "../config.h"
-#ifdef HAVE_MAD
 
 #include "gnusource.h"
 #include <stdio.h>
 #include <string.h>
 #include <jack/jack.h>
+#ifdef DYN_MAD
+#include "mad.h"
+#else
 #include <mad.h>
+#endif /* DYN_MAD */
 #include "xlplayer.h"
 #include "mp3dec.h"
 #include "bsdcompat.h"
@@ -48,7 +51,7 @@ static int mp3decode_get_frame(struct xlplayer *xlplayer)
    {
    struct mp3decode_vars *self = xlplayer->dec_data;
    size_t nb;
-   
+
    if (mad_frame_decode(&(self->frame), &(self->stream)) != 0)
       {
       if (self->stream.next_frame)
@@ -69,6 +72,12 @@ static int mp3decode_get_frame(struct xlplayer *xlplayer)
             mad_stream_buffer(&(self->stream), self->read_buffer, self->bytes_in_buffer);
             break;
          default:
+            if (self->stream.error)
+               {
+               //fprintf(stderr, "got error code 0x%04X\n", self->stream.error);
+               mad_stream_buffer(&(self->stream), self->read_buffer, self->bytes_in_buffer);
+               return -1;
+               }
             mad_stream_buffer(&(self->stream), self->read_buffer, self->bytes_in_buffer);
          }
       return -1;
@@ -81,8 +90,10 @@ static void mp3decode_eject(struct xlplayer *xlplayer)
    {
    struct mp3decode_vars *self = xlplayer->dec_data;
  
-   jack_ringbuffer_free(self->lrb);
-   jack_ringbuffer_free(self->rrb);
+   if (self->lrb)
+      jack_ringbuffer_free(self->lrb);
+   if (self->rrb)
+      jack_ringbuffer_free(self->rrb);
    if (self->resample)
       {
       if (xlplayer->src_data.data_in)
@@ -98,6 +109,10 @@ static void mp3decode_eject(struct xlplayer *xlplayer)
    fclose(self->fp);
    free(self->read_buffer);
    free(self);
+
+
+
+fprintf(stderr, "finished eject\n");
    }
 
 static void mp3decode_init(struct xlplayer *xlplayer)
@@ -105,10 +120,10 @@ static void mp3decode_init(struct xlplayer *xlplayer)
    struct mp3decode_vars *self = xlplayer->dec_data;
    struct mp3taginfo *ti = &self->taginfo;
    off_t start, end, offset;
-   int retcode, dump, index, rbsize;
+   int retcode, dump, index, rbsize, goterror;
    int src_error, luv1, luv2, samples;
    float size, seek_pc, frac, scale;
-    
+
    if (xlplayer->seek_s)
       {
       if (ti->tlen)
@@ -159,10 +174,13 @@ static void mp3decode_init(struct xlplayer *xlplayer)
          return;
          }
       mad_stream_buffer(&(self->stream), self->read_buffer, self->bytes_in_buffer);
-      for (dump = 0; dump < 2; dump++)
+      
+      for (dump = goterror = 0; dump < 3 || goterror; dump++)
          {
-         while ((retcode = mp3decode_get_frame(xlplayer)) < 0);
-         if (retcode == 0)
+         goterror = 0;
+         while ((retcode = mp3decode_get_frame(xlplayer)) < 0)
+            goterror = TRUE;
+         if (retcode == 0 || dump == 15)
             {
             mp3decode_eject(xlplayer);
             xlplayer->playmode = PM_STOPPED;
@@ -171,6 +189,26 @@ static void mp3decode_init(struct xlplayer *xlplayer)
             }
          }
       }
+   else
+      if (self->errors)
+         {
+         fprintf(stderr, "skipping past errors at start of file\n");
+         for (dump = goterror = 0; dump < 3 || goterror; dump++)
+            {
+            goterror = 0;
+            while ((retcode = mp3decode_get_frame(xlplayer)) < 0)
+               goterror = TRUE;
+            if (retcode == 0 || dump == 15)
+               {
+               fprintf(stderr, "giving up\n");
+               mp3decode_eject(xlplayer);
+               xlplayer->playmode = PM_STOPPED;
+               xlplayer->command = CMD_COMPLETE;
+               return;
+               }
+            }
+         }
+
    mad_synth_frame(&(self->synth), &(self->frame));
    self->nchannels = self->synth.pcm.channels;
    self->samplerate = self->synth.pcm.samplerate;
@@ -359,6 +397,7 @@ int mp3decode_reg(struct xlplayer *xlplayer)
       }
    mp3_tag_read(&self->taginfo, self->fp);
    start = ftell(self->fp);
+
    if (!(self->read_buffer = malloc(BSIZ)))
       {
       fprintf(stderr, "mp3decode_test_mp3ness: malloc failure\n");
@@ -377,7 +416,6 @@ int mp3decode_reg(struct xlplayer *xlplayer)
       }
    mad_synth_init(&(self->synth));
    mad_stream_init(&(self->stream));
-   self->stream.options = MAD_OPTION_IGNORECRC;
    mad_frame_init(&(self->frame));
    mad_stream_buffer(&(self->stream), self->read_buffer, self->bytes_in_buffer);
    self->playduration = 0.0F;
@@ -386,6 +424,7 @@ int mp3decode_reg(struct xlplayer *xlplayer)
       switch (mp3decode_get_frame(xlplayer))
          {
          case -1:
+            self->errors = TRUE;
             if (ftell(self->fp) - start < 32768L)
                continue;
          case 0:
@@ -404,5 +443,3 @@ int mp3decode_reg(struct xlplayer *xlplayer)
          }
       }
    }
-
-#endif /* HAVE_MAD */
