@@ -18,7 +18,6 @@
 */
 
 #include "../config.h"
-#ifdef HAVE_MAD
 
 #include <jack/ringbuffer.h>
 #include "xlplayer.h"
@@ -41,8 +40,7 @@ struct mp3decode_vars
    jack_ringbuffer_t *lrb;
    jack_ringbuffer_t *rrb;
    int initial_data;
+   int errors;
    };
 
 int mp3decode_reg(struct xlplayer *xlplayer);
-
-#endif /* HAVE_MAD */
