@@ -18,7 +18,6 @@
 */
 
 #include "../config.h"
-#ifdef HAVE_MAD
 
 #include <stdio.h>
 
@@ -70,4 +69,3 @@ void mp3_tag_read(struct mp3taginfo *ti, FILE *fp);
 void mp3_tag_cleanup(struct mp3taginfo *ti);
 struct chapter *mp3_tag_chapter_scan(struct mp3taginfo *ti, int time_ms);
 
-#endif /* HAVE_MAD */
