@@ -54,13 +54,13 @@ int oggdec_get_next_packet(struct oggdec_vars *self)
          ogg_sync_wrote(&self->oy, bytes);
          if (bytes == 0)
             {
-            fprintf(stderr, "get_next_packet: the end of the file appears to have been reached, unexpectedly\n");
+            fprintf(stderr, "oggdec_get_next_packet: the end of the file appears to have been reached, unexpectedly\n");
             return 0;
             }
          }
       if (ogg_stream_pagein(&self->os, &self->og))
          {
-         fprintf(stderr, "get_next_packet: call to ogg_stream_pagein failed, most likely this stream is multiplexed, which is not supported in IDJC");
+         fprintf(stderr, "oggdec_get_next_packet: call to ogg_stream_pagein failed, most likely this stream is either multiplexed or improperly terminated\n");
          return 0;
          }
       else
@@ -477,7 +477,8 @@ static off_t oggscan_eos(struct oggdec_vars *self, off_t offset, off_t offset_en
    off_t  retval;
    off_t  midpoint = (offset_end - offset) / 2 + offset;
    off_t  stored_mid = midpoint;
-   
+   int eos = FALSE, terminate = FALSE;
+
    fseeko(self->fp, midpoint, SEEK_SET);
    ogg_sync_reset(&self->oy);
    while ((retval = ogg_sync_pageseek(&self->oy, &self->og)) <= 0)
@@ -495,15 +496,18 @@ static off_t oggscan_eos(struct oggdec_vars *self, off_t offset, off_t offset_en
          ogg_sync_wrote(&self->oy, bytes);
          if (bytes == 0)
             {
-            fprintf(stderr, "oggscan_eos: unexpected file io error\n");
-            return offset_end;
+            fprintf(stderr, "oggscan_eos: unexpected file io error, the file is probably truncated\n");
+            terminate = TRUE;
+            midpoint = offset_end;
+            retval = 0;
+            break;
             }
          }
       }
  
-   if (ogg_page_serialno(&self->og) == serial)
+   if (terminate || ogg_page_serialno(&self->og) == serial)
       {
-      if (ogg_page_eos(&self->og))
+      if (terminate || (eos = ogg_page_eos(&self->og)) || offset + 1 >= offset_end)
          {
          /* we have found the last packet in the logical stream */
          /* make space for data about this logical stream */
@@ -529,8 +533,11 @@ static off_t oggscan_eos(struct oggdec_vars *self, off_t offset, off_t offset_en
         
          self->granule_count[self->n_streams - 1] = ogg_page_granulepos(&self->og);
          self->serial[self->n_streams - 1] = serial; 
+         if (!eos)
+            fprintf(stderr, "oggscan_eos: an unterminated stream was detected\n");
          return midpoint + retval;
          }
+      
       /* seek to the right next time */
       return oggscan_eos(self, midpoint, offset_end, serial);
       }
@@ -713,7 +720,7 @@ static struct oggdec_vars *oggdecode_get_metadata(char *pathname)
          start_time += self->duration[i] = self->granule_count[i] / (double)samplerate;
          self->total_duration += self->duration[i];
          }
-#if 1
+#if 0
       fprintf(stderr,
          "#####################\n"
          "beginning offset %d\n"
