@@ -33,7 +33,6 @@
 #include "oggdec.h"
 #include "flacdecode.h"
 #include "sndfiledecode.h"
-#include "mp4decode.h"
 #include "avcodecdecode.h"
 #include "bsdcompat.h"
 
@@ -48,6 +47,8 @@ typedef jack_default_audio_sample_t sample_t;
 static sample_t *fadeinlookuptable;
 static size_t fadeinlookuptable_numsamples;
 
+extern int have_mad;
+
 /* make_audio_to_float: convert the audio to the format used by jack and libsamplerate */
 float *xlplayer_make_audio_to_float(struct xlplayer *self, float *buffer, uint8_t *data, int num_samples, int bits_per_sample, int num_channels)
    {
@@ -305,12 +306,10 @@ static void *xlplayer_main(struct xlplayer *self)
 #endif
 #ifdef HAVE_AVCODEC
 #ifdef HAVE_AVFORMAT
-                    || ((!strcmp(extension, "m4a") || !strcmp(extension, "mp4") || !strcmp(extension, "wma") || !strcmp(extension, "avi")) && avcodecdecode_reg(self))
+                    || ((!strcmp(extension, "m4a") || !strcmp(extension, "mp4") || !strcmp(extension, "wma") || !strcmp(extension, "avi") || !strcmp(extension, "mpc") || !strcmp(extension, "ape")) && avcodecdecode_reg(self))
 #endif /* HAVE_AVFORMAT */
 #endif /* HAVE_AVCODEC */
-#ifdef HAVE_MAD
-       		    || (!strcmp(extension, "mp3") && mp3decode_reg(self))
-#endif
+       		    || (!strcmp(extension, "mp3") && have_mad && mp3decode_reg(self))
 	       )
 	       {
                self->playmode = PM_PLAYING;
