@@ -27,6 +27,7 @@ from ln_text import ln
 class jingles:
    def cleanup(self):
       self.stop.clicked()
+      self.saved_interlude = self.interlude_player_track
       self.interlude.set_active(False)
    
    def cb_doubleclick(self, treeview, path, column, user_data):
@@ -246,6 +247,8 @@ class jingles:
       
    def cb_interlude(self, widget, treeview):
       if widget.get_active():
+         if self.interlude_playing:
+            return
          treeselection = treeview.get_selection()
          model, iter = treeselection.get_selected()
          if iter == None:
@@ -266,12 +269,18 @@ class jingles:
             print "Failed to start the interlude player"
       else:
          if self.interlude_playing:
+            intertrack = os.path.split(self.interlude_player_track)[1]
             for each in self.liststore:
                item = str(each[2])
                if item[0]=="<":
                   each[2] = item[3:-4]
                   self.interlude_song = ""
                   break
+               elif item == intertrack:
+                  self.interlude.set_active(True)
+                  each[2] = "<b>" + intertrack + "</b>"
+                  self.interlude_song = intertrack
+                  return
             else:
                print "The interlude file is missing from the list."
             print "Shutting down the interlude player"
@@ -479,6 +488,7 @@ class jingles:
       self.playing = False
       self.interlude_pid = 0
       self.interlude_song= ""
+      self.interlude_playing = False
       self.load_jingles()
       self.jingleswinx = int_object(1)
       self.jingleswiny = int_object(1)
