@@ -21,7 +21,7 @@ __all__ = ['multitag']
 
 import pygtk
 pygtk.require('2.0')
-import gtk, os, sys
+import gtk, os, sys, subprocess
 try:
    import eyeD3
 except:
@@ -46,7 +46,7 @@ class mp4tagger(gtk.VBox):
          if line.startswith("idjcmixer: mp4tagread "):
             data += line[22:]
       kvplist = self.make_pairs(data)
-      recommended = [ u"artist", u"title", u"track", u"totaltracks", u"album", u"genre", u"date", u"comment" ]
+      recommended = [ u"artist", u"name", u"tracknum", u"album", u"genre", u"year" ]
       precede = u""
       for recommend in recommended:
          for key, value in kvplist:
@@ -54,8 +54,11 @@ class mp4tagger(gtk.VBox):
                break
          else:
             precede = precede + recommend + u"=\n"
+      print precede
+      print "----------"
+      print data
       self.textbuffer.set_text(precede + data)
-      
+
    def save_tag(self, pathname):
       kvp = self.make_pairs()
       text = u""
@@ -133,8 +136,7 @@ class vorbistagger(gtk.VBox):
          self.vc = "vorbiscomment"	# For standalone version
       if self.vc != "missing":
          try:
-            (write, read) = os.popen2([ self.vc, "--raw", pathname ])
-            write.close()
+            read = subprocess.Popen([ self.vc, "--raw", pathname ], stdout=subprocess.PIPE, close_fds=True).stdout
             data = read.read()
             read.close()
          except:
@@ -148,11 +150,11 @@ class vorbistagger(gtk.VBox):
          self.mf = "metaflac"	# For standalone version
       if self.mf != "missing":
          try:
-            (write, read) = os.popen2([ self.mf, "--no-utf8-convert", "--export-tags-to=-" , pathname ])
-            write.close()
+            read = subprocess.Popen([ self.mf, "--no-utf8-convert", "--export-tags-to=-" , pathname ], stdout=subprocess.PIPE, close_fds=True).stdout
             data = read.read()
             read.close()
-         except:
+         except Exception, inst:
+            print inst
             print "Problem reading in file", pathname
          else:
             self.load_tag(data)
@@ -165,7 +167,7 @@ class vorbistagger(gtk.VBox):
       precede = u""
       for recommend in recommended:
          for key, value in kvplist:
-            if key == recommend:
+            if key.lower() == recommend.lower():
                break
          else:
             precede = precede + recommend + u"=\n"
@@ -189,15 +191,14 @@ class vorbistagger(gtk.VBox):
          text = u""
          for key, value in kvp:
             text = text + key + "=" + value + "\n"
-         write, read = os.popen2([self.vc, "--raw", "-w", pathname]) 
          try:
+            write = subprocess.Popen([self.vc, "--raw", "-w", pathname], stdin=subprocess.PIPE, close_fds=True).stdin
             write.write(text)
             write.close()
-            read.read()
-            read.close()
-         except BrokenPipe:
-            pass
-	 print "Ogg tag saved"
+         except:
+            print "failed to save Ogg tag"
+         else:
+            print "Ogg tag saved"
       
    def save_flac_tag(self, pathname):
       if self.mf != "missing":
@@ -205,15 +206,14 @@ class vorbistagger(gtk.VBox):
          text = u""
          for key, value in kvp:
             text = text + key + "=" + value + "\n"
-         write, read = os.popen2(["metaflac", "--no-utf8-convert", "--remove-all-tags", "--import-tags-from=-", pathname])
-	 try:
+         try:
+            write = subprocess.Popen([self.mf, "--no-utf8-convert", "--remove-all-tags", "--import-tags-from=-", pathname], stdin=subprocess.PIPE, close_fds=True).stdin
             write.write(text)
             write.close()
-            read.read()
-            read.close()
-         except BrokenPipe:
-            pass
-         print "Flac tag saved"
+         except:
+            print "failed to save FLAC tag"
+         else:
+            print "FLAC tag saved"
       
    def make_pairs(self, data = None):	# Returns a list of tuples of key value pairs
       kvp = [ ]			# Any keys containing a space are rejected
@@ -487,7 +487,8 @@ class multitag:
          supported.append("spx")
       extension = os.path.splitext(pathname)[1][1:].lower()
       if supported.count(extension) != 1:
-         print "File type", extension, "is not supported."
+         if extension:
+            print "File type", extension, "is not supported for tagging"
          return False
       else:
          return extension
