@@ -25,6 +25,9 @@ except:
    import pango
 
 from idjc_config import *
+from ln_text import ln
+
+import time
 
 # A mutually exclusive list of dialogs so that only one can be on screen at a time
 # The dialogs below can call the hide method to remove any other dialogs
@@ -154,3 +157,108 @@ class autodisconnection_notification_dialog(gtk.Dialog):
          dial_group.add(self)
       self.dial_group = dial_group
       # Dialog is not shown upon creation, but rather is (re)shown when needed.
+
+class ReconnectionDialog(gtk.Dialog):
+   td = (0.0, 10.0, 10.0, 60.0)
+   
+   def update_countdown_text(self):
+      remaining = self.remaining
+      self.remaining = int(self.event_time - time.time())
+      if self.remaining != remaining:
+         self.label2.set_text(ln.reconnection_text_2 % self.remaining)
+         if self.remaining == 0:
+            self.hide()
+            while gtk.events_pending():
+               gtk.main_iteration()
+            self.tab.server_connect.set_active(True)
+            if self.tab.server_connect.get_active() == False:
+               self.activate()
+   
+   def run(self):
+      if self.active:
+         self.update_countdown_text()
+   
+   def activate(self):
+      if self.config is None:
+         self.config = self.tab.source_client_gui.parent.prefs_window.recon_config
+      if self.active == False:
+         self.trycount = 1
+         if self.config.limited_delays.get_active():
+            self.limited_delays = True
+            self.td = [0.0]
+            for each in self.config.csl.get_text().split(","):
+               try:
+                  x = float(each)
+               except:
+                  pass
+               else:
+                  if x >= 1.0:
+                    self.td.append(x)
+         else:
+            self.limited_delays = False
+         self.active = True
+      else:
+         self.trycount += 1
+      
+      if self.limited_delays:
+         if self.trycount >= len(self.td):
+            self.deactivate()
+            self.tab.scg.disconnected_dialog.present()
+            return
+         else:
+            self.remaining = self.td[self.trycount]
+      else:
+         self.remaining = 5.0
+      self.event_time = time.time() + self.remaining
+      self.update_countdown_text()
+      if self.limited_delays:
+         self.label3.set_text(ln.reconnection_text_3 % (self.trycount, len(self.td) - 1))
+      else:
+         self.label3.set_text(ln.reconnection_text_3b % self.trycount)
+      if self.config.visible.get_active():
+         self.present()
+      else:
+         self.realize()
+   
+   def deactivate(self):
+      if self.active:
+         self.hide()
+         self.active = False
+
+   def cb_response(self, dialog, response):
+      if response == gtk.RESPONSE_CANCEL:
+         self.deactivate()
+      if response == gtk.RESPONSE_OK:
+         self.event_time = time.time() + 0.25
+
+   def cb_delete(self, widget, event):
+      self.deactivate()
+      return True
+
+   def __init__(self, tab):
+      self.tab = tab
+      gtk.Dialog.__init__(self, ln.connection_lost, None, gtk.DIALOG_DESTROY_WITH_PARENT, (gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL, ln.try_now, gtk.RESPONSE_OK))
+      self.set_resizable(False)
+      
+      self.vb = gtk.VBox() # bug workaround
+      self.vbox.pack_start(self.vb)
+      self.vb.show()
+      self.vb.set_border_width(10)
+      self.vb.set_spacing(10)
+      
+      self.set_icon_from_file(pkgdatadir + "icon" + gfext)
+      self.connect("delete-event", self.cb_delete)
+      self.connect("response", self.cb_response)
+      
+      self.label1 = gtk.Label(ln.reconnection_text_1 % (tab.numeric_id + 1))
+      self.label2 = gtk.Label(ln.reconnection_text_2 % self.td[1])
+      self.label3 = gtk.Label(ln.reconnection_text_3 % (1, len(self.td) - 1))
+      for each in (self.label1, self.label2, self.label3):
+         attrlist = pango.AttrList()
+         attrlist.insert(pango.AttrSize(12500, 0, len(each.get_text())))
+         each.set_attributes(attrlist)
+         self.vb.add(each)
+         each.show()
+      
+      self.config = None   # unavailable just yet
+      self.active = False
