@@ -19,10 +19,6 @@
 #   along with this program in the file entitled COPYING.
 #   If not, see <http://www.gnu.org/licenses/>
 
-#   I t e m s   w i t h   n o   m a t c h   i n   e n _ G B _ t e x t . p y 
- 
-autopause = "Automatische Aufnahmepause"
-
 #   T h e   f o l l o w i n g   a r e   r e g u l a r   t r a n s l a t i o n s 
  
 about_tab = "Über"
@@ -117,16 +113,10 @@ general_tab = "Grundeinstellungen"
 
 genre = "Musikrichtung:"
 
-headroom = "Headroom"
-
-hysteresis = "Hysteresis"
-
 idjc_shutdown = "IDJC Beenden"
 
 initial_player_settings = "Einstellungen nach Programmstart"
 
-invert = "Umkehren"
-
 irc_message_timer = "IRC Nachrichten Timer"
 
 is_recording = "IDJC nimmt gerade auf."
@@ -163,6 +153,14 @@ message = "Nachricht:"
 
 metadata = "Metadaten: "
 
+metadata_source_last_played = "Zuletzt gespielt"
+
+metadata_source_left_deck = "Linker Player"
+
+metadata_source_right_deck = "Rechter Player"
+
+metadata_source_tip = "Dieses Feld left fest, welcher Player die Metadaten für den Stream bereitstellen soll."
+
 mic_in_phones = "Hearing your voice in your headphones (somewhat delayed) can be distracting for some, which is why this feature exists."
 
 mic_peak = "Mik Spitze"
@@ -321,6 +319,54 @@ use_jack_srate_tip = "No additional resampling will occur. The stream sample rat
 
 #af_sharp_tip = "This bass cut filter is provided for people who have severe mains hum or an infrasound problem due to poor audio components."
 
+#agc_compressor = "Compressor"
+
+#agc_controls = "Processed Audio Controls"
+
+#agc_cutoff = "Cutoff Frequency"
+
+#agc_deessbias = "Bias"
+
+#agc_deesser = "De-esser"
+
+#agc_ducker = "Ducker"
+
+#agc_duckhold = "Hold"
+
+#agc_duckrelease = "Release"
+
+#agc_gain = "Gain"
+
+#agc_hfdetail = "HF Detail"
+
+#agc_hfmulti = "Effect"
+
+#agc_highpass = "High Pass Filter"
+
+#agc_left = "Left"
+
+#agc_level = "Level"
+
+#agc_lfdetail = "LF Detail"
+
+#agc_lfmulti = "Effect"
+
+#agc_limit = "Limit"
+
+#agc_nggain = "Gain"
+
+#agc_ngthresh = "Threshold"
+
+#agc_noisegate = "Noise Gate"
+
+#agc_other_options = "Options"
+
+#agc_phaserotator = "Phase Rotator"
+
+#agc_ratio = "Boost"
+
+#agc_right = "Right"
+
 #announce_tip = "Enter the message you want to send here. To include the track currently playing use %s. You can also include colours using Ctrl+K (standard X-Chat/mIRC method) or from the context menu (right click)."
 
 #app_exit_tip = "When IDJC exits run the commands to the right."
@@ -335,7 +381,7 @@ use_jack_srate_tip = "No additional resampling will occur. The stream sample rat
 
 #attenuate_right_tip = "Use this to attenuate the right microphone signal so that it matches the signal level of the left microphone. Use this when the right microphone signal is generally stronger than the left."
 
-#audio_meters = "Audio Meters"
+#audio_meters = "Meters"
 
 #auto_start_player_tip = "Have one of the players start automatically when a radio server connection is successfully made."
 
@@ -389,16 +435,58 @@ use_jack_srate_tip = "No additional resampling will occur. The stream sample rat
 
 #comp_ratio = "Ratio"
 
-#comp_release = "Decay"
+#comp_release = "Release"
 
 #compression_meter_tip = "A meter indicating the current amount of attenuation being applied to each microphone input by the compressor."
 
+#connection_lost = "Connection Lost"
+
+#contact_info = " Shoutcast Contact Info "
+
 #cross_left_tip = "Move the crossfader fully left."
 
+#cross_middle_tip = "Move the crossfader to the middle of its range of travel."
+
+#cross_pattern_tip = "This changes the response curve of the crossfader."
+
 #cross_right_tip = "Move the crossfader fully right."
 
+#crossfader = "Crossfader"
+
 #crossfader_tip = "The crossfader."
 
+#crosspass = "Pass"
+
+#dbalbum = "Album"
+
+#dbartist = "Artist"
+
+#dbbitrate = "Bitrate"
+
+#dbcollapse = "_Collapse"
+
+#dbduration = "Duration"
+
+#dbexpand = "_Expand"
+
+#dbfilename = "Filename"
+
+#dbfilters = " Filters "
+
+#dbfound = "(%d)"
+
+#dbfuzzysearch = "Fuzzy Search"
+
+#dbpath = "Path"
+
+#dbtitle = "Title"
+
+#dbtrack = "Track"
+
+#dbunknown = "<unknown>"
+
+#dbwhere = "WHERE"
+
 #default_normalizer_tip = "Load the recommended settings."
 
 #delete_mode_tip = "This button toggles delete mode which allows the removal of tracks from the playlist by mouse clicking them."
@@ -423,11 +511,11 @@ use_jack_srate_tip = "No additional resampling will occur. The stream sample rat
 
 #down_arrow_tip = "This moves the highlighted track down the playlist order."
 
-#drc_attack_tip = "The speed at which signal attenuation is applied. Lower equals faster and equates to how much more attenuation is to be applied per audio sample as a fraction towards the computed ideal level. A very low number would be more responsive but will remove punchiness from the voice. A sensible setting would be 100."
+#drc_attack_tip = "The speed at which signal attenuation is applied. Lower equals faster and is a time constant in milliseconds. A very low number would be more responsive but will remove punchiness from the voice. A sensible setting would be 2.25ms provided the 30ms RMS filter is in use."
 
 #drc_deess_tip = "This reduces the impact of S T and P sounds by providing a second audio signal path to the compressor which performs a kind of audio processing to isolate those sounds. The higher the De-ess figure the more dominant this second audio path becomes. Making a test recording is the best way to find the ideal level however values above 10 are probably not sensible but are included for illustrating the full effect."
 
-#drc_ducking_hold_tip = "This controls the number of audio samples that need to pass before ducking is released. A sensible figure would be 30000 but the ideal figure depends on your speaking style."
+#drc_ducking_hold_tip = "This is the time delay in milliseconds before ducking attenuation starts to be released. A sensible figure would be 680ms but the ideal figure depends to some extent on your speaking style."
 
 #drc_ducking_ratio_tip = "Ducking is a feature that reduces the sound level of the music players when the DJ is talking with the microphone on. This allows the DJ to talk over the music with ease and works by taking the amount of signal attenuation applied by the compressor and multiplying it by the ducking factor (note: this widget controls the ducking factor) to calculate a level of attenuation to apply to the music players. A sensible level would be 1.6 but it largely depends on how much compression you are using."
 
@@ -443,13 +531,13 @@ use_jack_srate_tip = "No additional resampling will occur. The stream sample rat
 
 #drc_ratio_tip = "Adjusts the compression ratio applied to the microphone input. The bigger the number the more compressed the sound. A sensible value for this would be 3 or 3.5. To deactivate this feature choose 0. Consult the web for more information on the subject of 'dynamic range compression'."
 
-#drc_release_tip = "Decay is the opposite of attack and is also commonly called release and relates to how quickly the compressor releases signal attenuation when the microphone signal level drops. The higher this figure the longer it takes. A sensible setting would be 8000. Too high a figure will result in an audio artifact known as compressor pump where the sound level changes in a notably rhythmic fashion."
+#drc_release_tip = "Release is the opposite of attack and relates to how quickly the compressor releases signal attenuation when the microphone signal level drops. The higher this figure the longer it takes. A sensible setting would be 180ms. Too high a figure will result in an audio artifact known as compressor pump where the sound level changes in a notably rhythmic fashion."
 
 #elapsed_recording = "Elapsed:"
 
 #enable_message_timer_tip = "This widget enables the IRC message timer which broadcasts a message periodically to the specified channels."
 
-#enable_stream_normalizer_tip = "This feature is provided to make the various pieces of music that are played of a more uniform loudness level which is standard practice by 'real' radio stations. The default settings are likely to be sufficient however you may adjust them and you can compare the effect by clicking the 'Stream Mon.' button in the main application window which will allow you to compare the processed with the non-processed audio."
+#enable_stream_normalizer_tip = "This feature is provided to make the various pieces of music that are played of a more uniform loudness level which is standard practice by 'real' radio stations. The default settings are likely to be sufficient however you may adjust them and you can compare the effect by clicking the 'Monitor Mix' 'Stream' button in the main application window which will allow you to compare the processed with the non-processed audio."
 
 #enable_tooltips = "Enable tooltips"
 
@@ -461,10 +549,6 @@ use_jack_srate_tip = "No additional resampling will occur. The stream sample rat
 
 #event_tab = "Event"
 
-#extm3u = "Process the metadata in extended m3u files"
-
-#extm3u_tip = "This feature is either useful or a hindrance depending on the quality of the information provided within the m3u files concerned. When this feature is turned off metadata is obtained from the media files instead. It also affects whether the m3u files will be extended or not when saving playlists."
-
 #fadeout_toggle = "Fadeout"
 
 #fall = "Fall"
@@ -473,14 +557,32 @@ use_jack_srate_tip = "No additional resampling will occur. The stream sample rat
 
 #fastest_resample = "Fastest"
 
+#feature_disabled = "Feature Disabled"
+
 #filter_fast = "3ms RMS"
 
 #filter_slow = "30ms RMS"
 
+#flac16_tip = "The ideal bit width for streaming assuming you have the bandwidth to spare."
+
+#flac20_tip = "Ideal for very high quality streaming or recording although not as compatible as 16 bit."
+
+#flac24_tip = "The highest quality audio format available within IDJC. Recommended for pre-recording."
+
+#flac_bitrates = ('16 Bit', '20 Bit', '24 Bit')
+
+#flac_streamtab_tip = "This chooses the OggFLAC format for streaming and recording."
+
+#flacmetadata = "Metadata"
+
+#flacmetadata_tip = "You can prevent the sending of metadata by turning this feature off. This will prevent certain players from dropping the stream or inserting an audible gap every time the song title changes."
+
 #format = " Format "
 
 #format_info_bar_tip = "Information about how the encoder is currently configured is displayed here."
 
+#formats = " Supported Media Formats "
+
 #fully_featured_tip = "Run in full functionality mode which uses more CPU power."
 
 #genre_tip = "The musical genres you are likely to play."
@@ -489,6 +591,8 @@ use_jack_srate_tip = "No additional resampling will occur. The stream sample rat
 
 #green_phone_tip = "Mix voice over IP audio to the output stream."
 
+#headroom = "Player headroom when the microphone is open (dB)"
+
 #headroom_tip = "The number of dB to reduce the music players' sound level by when the microphone is switched on. A sensible setting would be 3.0 or even higher if you are not going to use ducking."
 
 #high_quality_abbrev = "HQ"
@@ -499,16 +603,54 @@ use_jack_srate_tip = "No additional resampling will occur. The stream sample rat
 #Example 1: 192.168.1.4
 #Example 2: localhost"""
 
+#hysteresis = "Hyster."
+
+#icy_aim = "AIM:"
+
+#icy_aim_tip = "Connection info for AOL instant messenger goes here."
+
+#icy_icq = "ICQ:"
+
+#icy_icq_tip = "ICQ instant messenger connection info goes here."
+
+#icy_irc = "IRC:"
+
+#icy_irc_tip = "Internet Relay Chat connection info goes here."
+
 #id3_tag = "ID3 Tag"
 
+#idjc_launch_failed = "IDJC Launch Failed"
+
 #interval = "Interval:"
 
+#invert_left = "Invert left mic audio"
+
 #invert_left_tip = "Performs phase inversion on the left microphone signal. Use this to make both microphones be in phase with one another and to affect phase in relation to your voice with respect to the headphones."
 
+#invert_right = "Invert right mic audio"
+
 #invert_right_tip = "Performs phase inversion on the right microphone signal. Use this to make both microphones be in phase with one another and to affect phase in relation to your voice with respect to the headphones."
 
 #irc_channels_tip = "A comma separated list of IRC channels. Some IRC servers require that you also be logged into the channel before you can announce there."
 
+#jack_connection_failed = """The JACK sound server needs to be running in order to run IDJC.
+#In order to manually start it try something like:
+#
+#	$ jackd -d alsa -r 44100 -p 2048
+#
+#If you would like JACK to start automatically with your user specified parameters try something like this, which will create a file called .jackdrc in your home directory:
+#
+#	$ echo "/usr/bin/jackd -d alsa -r 44100" > ~/.jackdrc
+#
+#If you have already done this it is possible another application or non-JACK sound server is using the sound card.
+#
+#Possible remedies would be to close the other audio app or configure the sound server to go into suspend mode after a brief amount of idle time.
+#
+#If you are trying to connect to a named jack server, either set the environment variable JACK_DEFAULT_SERVER to that name or launch IDJC with the -j jackservername option. For example:
+#
+#	 $ jackd -n xyzzy -d alsa -r 44100 -p 2048 &
+#	 $ idjc -p profilename -j xyzzy"""
+
 #jack_entry = """Enter the name of the JACK audio port with which to bind and then click the set button to the right.
 #Typing 'jack_lsp -p' in a console will give you a list of valid JACK audio ports. Note that inputs will only bind to output ports and outputs will only bind to input ports."""
 
@@ -544,8 +686,18 @@ use_jack_srate_tip = "No additional resampling will occur. The stream sample rat
 
 #login_tip = "Icecast servers can be configured to have individual per-user source passwords to facilitate efficient password revocation. This requires that every user must have a separate login name which is entered here. The default login name is 'source'."
 
+#lower_vorbis = "Lower %"
+
 #make_public_tip = "Publish your radio station on a listings website. The website in question will depend on how the server to which you connect is configured."
 
+#media_flat = "Flat"
+
+#media_tree = "Tree"
+
+#media_viewer_title = " P3 Database View (%s) "
+
+#mediafilter_all = "Supported media"
+
 #message_timer_interval = "The time period in minutes between messages. The minimum 1 minute is intended for testing purposes."
 
 #meta_tag = "Meta Tag"
@@ -554,8 +706,16 @@ use_jack_srate_tip = "No additional resampling will occur. The stream sample rat
 
 #metadata_entry_tip = "You can enter text to accompany the stream here, as well as incorporating the title of the currently playing track by including %s at the appropriate point."
 
+#metadata_source_crossfader = "Crossfader"
+
+#metadata_source_label = "Metadata Source"
+
+#metadata_source_none = "None"
+
 #metadata_update_tip = "Update the metadata."
 
+#mic_agc = "Use AGC for mic audio processing (experimental)"
+
 #mic_aux_mutex = "Make Mic and Aux buttons mutually exclusive"
 
 #mic_aux_mutex_tip = "This feature ensures that the microphone and auxiliary inputs can not both be on at the same time. This allows the DJ to be able to switch between the two with only one mouse click. It may be of use to those who mix a lot of external audio, or who wish to use the auxiliary input as a secondary microphone source with different audio processing."
@@ -570,17 +730,29 @@ use_jack_srate_tip = "No additional resampling will occur. The stream sample rat
 
 #mic_peak_toggle_tip = "Controls whether to display a peak-hold signal level meter in the main application window indicating the signal strength of the individual microphone audio levels."
 
-#mic_to_dj = "Microphone audio audible in headphones"
+#mic_to_dj = "Send microphone audio (mono) to the DJ's headphones"
 
 #mic_toggle_tip = "This button toggles the microphone input for both the left and the right microphones. To select microphones individually, right click on this button."
 
 #mic_vu_meter_tip = "A VU meter for the microphone audio."
 
+#middle = "Middle"
+
 #misc_features = "Miscellaneous Features"
 
 #missing_lame = "MP3 Not available"
 
-#mount_point_tip = "The mount point, which is not required when dealing with SHOUTcast servers. A typical mount point might be /listen or /listen.ogg. It is recommended that Ogg streams have a mount point ending in .ogg for the sake of listener client compatibility."
+#mixer_crash = "The mixer module crashed during initialisation."
+
+#monitor = "Monitor Mix"
+
+#monitor_dj = "DJ"
+
+#monitor_stream = "Stream"
+
+#mono = "Mono"
+
+#mount_point_tip = "The mount point, which is not required when dealing with Shoutcast servers. A typical mount point might be /listen or /listen.ogg. It is recommended that Ogg streams have a mount point ending in .ogg for the sake of listener client compatibility."
 
 #mp3_compat_tip = "The type of mpeg header used in the mp3 stream or either s-rate or freeformat. Freeformat indicates that the bitrate is not specified in the header since it is non-standard, rather the listener client has to figure out what the bitrate is by itself and not all of them are capable of doing that. In short you'll be streaming something many listeners may not be able to listen to. S-rate indicates the sample rate you have selected is not compatible with mp3 and you'll need to change it if you want to stream."
 
@@ -588,6 +760,8 @@ use_jack_srate_tip = "No additional resampling will occur. The stream sample rat
 
 #mp3_stereo_type_tip = "Mono is self explanatory. Joint Stereo is recommended below 160kb/s where regular Stereo might result in metallic sounding distortion. At higher bitrates regular stereo sounds better due to superior channel separation."
 
+#mp3_streamtab_tip = "Clicking this tab selects the mp3 file format for streaming and contains settings for configuring the mp3 encoder."
+
 #mp3_utf8 = "Use utf-8 encoding when streaming mp3 metadata"
 
 #mp3_utf8_tip = "It is standard practice when streaming metadata in mp3 streams to use iso-8859-1 character encoding. This is unfortunate since with utf-8 practically anything can be encoded. In deciding whether to use this feature you have to consider the proportion of listener clients that will be capable of correctly decoding text encoded with utf-8."
@@ -604,13 +778,13 @@ use_jack_srate_tip = "No additional resampling will occur. The stream sample rat
 
 #ng_delay = "Delay"
 
-#ng_delay_tip = "This is the number of samples to delay before switching the noise gate on. It's purpose is to make the noise gate ignore very brief pauses in speech. A sensible figure would be 800."
+#ng_delay_tip = "This is the number of milliseconds to wait before closing the noise gate. It's purpose is to make the noise gate ignore very brief pauses in speech. A sensible figure would be 18ms."
 
-#ng_fall_tip = "This controls how quickly the sound level will fall to the specified attenuation level when the noise gate switches on. Larger numbers = slower. A sensible value would be 500."
+#ng_fall_tip = "This controls the speed at which the gate attenuation can increase. The value is a time constant expressed in milliseconds. A sensible value would be 12ms."
 
 #ng_hyster_tip = "This setting applies hysteresis to the noise gate so that it does not continuously switch itself on and off. A sensible setting would be 6 but it depends on how variable the noise floor is."
 
-#ng_rise_tip = "This is the rise speed with smaller numbers being faster and relates to how quickly the noise gate switches off and allows the full sound level of speech to pass through. A sensible value would be 55."
+#ng_rise_tip = "This is the rise speed as a time constant and relates to how quickly the noise gate opens, allowing the full sound level of speech to pass through. A sensible value would be 1.2ms."
 
 #ng_thresh_tip = "The noise gate is provided to apply a little audio expansion to soften the initial punchiness that the compressor lends to the audio when silence is broken while at the same time improving the signal to noise ratio. The 'Threshold' setting should be set about 10dB above the noise floor so that the noise gate is active when you are not talking."
 
@@ -620,6 +794,12 @@ use_jack_srate_tip = "No additional resampling will occur. The stream sample rat
 
 #no_more_ask = "Don't ask again"
 
+#no_mp3_stream_available = ('MP3 streaming is unavailable,', 'and as a consequence', 'Shoutcast is also disabled.', '', 'Icecast Ogg streaming only.')
+
+#no_mp3_stream_available_tip = """Due to concerns over software patents or through oversight, the person or organisation who compiled this program neglected to include support for mp3 encoding.
+# 
+#In order to stream mp3 with Shoutcast you need to either locate and install an unrestricted IDJC package or failing that, compile your own from source."""
+
 #no_resample = "Use JACK sample rate"
 
 #noise_gate = "Noise Gate"
@@ -638,20 +818,12 @@ use_jack_srate_tip = "No additional resampling will occur. The stream sample rat
 
 #normrise = "Rise"
 
-#ogg_bitrate_max_tip = "The upper bitrate limit relative to the nominal bitrate. This is an advisory limit and it may be exceeded."
-
-#ogg_bitrate_min_tip = "The minimum bitrate in relative terms. For streaming it is recommended that you set a minimum bitrate although setting any upper and lower limits will result in much higher CPU usage and lower sound quality."
-
-#ogg_bitrate_neg_rel = "Min (-rel)"
-
-#ogg_bitrate_nominal = "Nominal Bitrate"
-
-#ogg_bitrate_pos_rel = "Max (+rel)"
-
-#ogg_bitrate_tip = "The nominal Ogg/Vorbis bitrate in kilobits per second."
+#ogg_streamtab_tip = "Clicking this tab selects the Ogg family of file formats."
 
 #open_aux_element = "Switch to Aux input"
 
+#other_mic_options = "Other Options"
+
 #pass_button_tip = "This button causes the crossfader to move to the opposite side at a speed determined by the speed selector to the left."
 
 #pass_speed_tip = "The time in seconds that the crossfader will take to automatically pass across when the button to the right is clicked."
@@ -696,6 +868,18 @@ use_jack_srate_tip = "No additional resampling will occur. The stream sample rat
 #
 #'Cue Up' is similar to manual except that the next track in the playlist will also be highlighted."""
 
+#playlistfilter_all = "All file types"
+
+#playlistfilter_supported = "Playlist types (*.m3u, *.xspf, *.pls)"
+
+#playlisttype_expander = "Select File Type "
+
+#playlisttype_extension = (('By Extension', ''), ('M3U playlist', 'm3u'), ('XSPF playlist', 'xspf'), ('PLS playlist', 'pls'))
+
+#playlisttype_header1 = "File Type"
+
+#playlisttype_header2 = "Extension"
+
 #popupwindowplayduration = "Total play duration %s"
 
 #popupwindowplaying = "Playing track %d of %d"
@@ -710,21 +894,49 @@ use_jack_srate_tip = "No additional resampling will occur. The stream sample rat
 
 #previous_tip = "Previous track."
 
+#profile_already_in_use = """IDJC could not be started because the profile is currently in use by another instance of IDJC.
+#
+#If you wish to run more than one instance of IDJC concurrently then in addition to using a different profile you also need to be running an additional JACK sound server.
+#
+#For further information refer to the -p and -j command line options in the IDJC man page and also to the -n option for starting jackd."""
+
 #profile_import_body = """You can choose to import settings from
 #one of the existing profiles
 #listed in the drop down box below."""
 
+#prokyon3_connect = "Database Connect"
+
+#prokyon3_database = "Database:"
+
+#prokyon3_frame_text = "Prokyon3 Database"
+
+#prokyon3_nosql = "Python module MySQLdb required"
+
+#prokyon3_password = "Password:"
+
+#prokyon3_user = "User:"
+
 #r = "R"
 
 #rec_directory_tip = "Choose which directory you want to save to. All file names will be in a timestamp format and have either an ogg or mp3 file extension. Important: you need to select a directory to which you have adequate write permission."
 
 #rec_source_tip = "Chooses which stream to record. If the stream isn't running the encoder will be started for you. Remember to make sure the encoder settings are to your liking before you start recording."
 
+#reconnection_text_1 = "The connection to the server in tab %s has failed."
+
+#reconnection_text_2 = "Automatic reconnect in %d seconds."
+
+#reconnection_text_3 = "Try %d of %d."
+
 #record_artist = "Artist:"
 
 #record_tab_tip = "Each one of these tabs represents a separate stream recorder. The LED indicator colours represent the following: Clear=Stopped Yellow=Paused Red=Recording."
 
-#record_tip = "Start recording."
+#record_tip = """Start recording.
+#
+#If this button is greyed out it could mean the encoder settings are not valid. This can be fixed by using one of the approved sample rates for mp3 or by choosing a sensible samplerate and bitrate combination for Ogg.
+#
+#Also check that you have write permission on the folder you have selected to record to."""
 
 #recording_time_tip = "Recording time elapsed."
 
@@ -738,6 +950,8 @@ use_jack_srate_tip = "No additional resampling will occur. The stream sample rat
 
 #resample_quality = "Quality"
 
+#response = "Response"
+
 #restore_session_tip = "When starting IDJC most of the main window settings will be as they were left. As an alternative you may specify below how you want the various settings to be when IDJC starts."
 
 #right_mic_stereo_tip = "This controls the stereo balance of the right microphone."
@@ -770,7 +984,11 @@ use_jack_srate_tip = "No additional resampling will occur. The stream sample rat
 
 #server_port = "Port:"
 
-#server_type_tip = "IDJC can connect to both Icecast and SHOUTcast servers. For this to be successful you need to specify the type of server that you wish to connect to since each type has a different connection protocol."
+#server_type_icecast2 = "Icecast 2"
+
+#server_type_shoutcast = "Shoutcast"
+
+#server_type_tip = "IDJC can connect to both Icecast and Shoutcast servers. For this to be successful you need to specify the type of server that you wish to connect to since each type has a different connection protocol."
 
 #server_window_open_tip = "Open the radio server connection window."
 
@@ -784,6 +1002,26 @@ use_jack_srate_tip = "No additional resampling will occur. The stream sample rat
 
 #speed_variance = "Enable the main-player speed/pitch controls"
 
+#speex_complexity = "CPU"
+
+#speex_complexity_tip = "This sets the level of complexity in the encoder. Higher values use more CPU but result in better sounding audio though not as great an improvement as you would get by increasing the quality setting to the left."
+
+#speex_metadata_tip = "Sending metadata may cause listener clients to misbehave when the metadata changes. By keeping this feature turned off you can avoid that."
+
+#speex_mode = "Mode"
+
+#speex_mode_tip = "This is the audio bandwidth selector. Ultra Wide Band has a bandwidth of 16kHz; Wide Band, 8kHz; Narrow Band, 4kHz. The samplerate is twice the value of the selected bandwidth consequently all settings in the samplerate pane to the left will be disregarded apart from the resample quality setting."
+
+#speex_modes = ('Ultra Wide Band', 'Wide Band', 'Narrow Band')
+
+#speex_quality = "Quality"
+
+#speex_quality_tip = "This picks an appropriate bitrate for the selected bandwidth on a quality metric. Q8 is a good choice for artifact-free speech and Q10 would be the ideal choice for music."
+
+#speex_stereo_tip = "Apply intensity stereo to the audio stream. This is a very efficient implementation of stereo but is only really suited to voice."
+
+#speex_streamtab_tip = "This chooses the Speex speech format for streaming and recording."
+
 #standard_tags = "Standard Tags"
 
 #start_mini_full = "Indicates which mode IDJC will be in when launched."
@@ -824,17 +1062,21 @@ use_jack_srate_tip = "No additional resampling will occur. The stream sample rat
 
 #stream_mic_vu = "Stream + Mic VU"
 
-#stream_mon_tip = "In IDJC there are are two audio paths and this 'Stream Monitor' button toggles between them. When it is active you can hear what the listeners are hearing including the effects of the crossfader. Stream Mon needs to be off in order to make proper use of the VOIP features."
+#stream_mon_tip = "In IDJC there are are two audio paths and this 'Monitor Mix' control toggles between them. When 'Stream' is active you can hear what the listeners are hearing including the effects of the crossfader. 'Monitor Mix' needs to be set to 'DJ' in order to make proper use of the VOIP features."
 
-#stream_monitor = "Stream Mon."
+#stream_monitor = "Monitor Stream Mix"
 
 #stream_normalizer = "Stream Normaliser"
 
 #stream_peak_meter_tip = "A peak hold meter indicating the signal strength of the stream audio."
 
-#stream_resample = "Sample rate"
+#stream_resample = " Sample rate "
 
-#stream_tab_tip = "Each one of these tabs represents a separate radio streamer. The LED indicator colours represent the following: Clear=Disconnected Yellow=Awaiting connection. Green=Connected. Flashing=Packet loss due to a bad connection."
+#stream_status_bar_toggle = "Stream Status"
+
+#stream_status_tip = "Controls whether to display a stream status meter in the main window."
+
+#stream_tab_tip = "Each one of these tabs represents a separate radio streamer. The LED indicator colours represent the following: Clear=No connection Yellow=Awaiting authentication. Green=Connected. Flashing=Packet loss due to a bad connection."
 
 #stream_tip = "Make output from this player available for streaming."
 
@@ -842,6 +1084,10 @@ use_jack_srate_tip = "No additional resampling will occur. The stream sample rat
 
 #streamer_resample_quality = "This selects the audio resampling method to be used, efficiency versus quality. Highest mode offers the best sound quality but also uses the most CPU (not recommended for systems built before 2006). Fastest mode while it uses by far the least amount of CPU should be avoided if at all possible."
 
+#streams = "Streams"
+
+#streams_tip = "This indicates the state of the various streams. Flashing means stream packets are being discarded because of network congestion. Partial red means the send buffer is partially full indicating difficulty communicating with the server. Green means everything is okay."
+
 #tag_album = "Album:"
 
 #tag_artist = "Artist:"
@@ -850,31 +1096,57 @@ use_jack_srate_tip = "No additional resampling will occur. The stream sample rat
 
 #test_monitor = " Test / Monitor "
 
+#time = "Time"
+
 #to_install_lame = ('LAME needs to be installed', 'in order to stream or record', 'in mp3 format.')
 
 #track_announcer_latency_tip = "A delay to the displaying of the change of track information in IRC. The idea is to match this number to the average audio latency in seconds that the listeners will be experiencing. Ten to fifteen seconds typically."
 
+#try_now = "Try Now"
+
+#twodblimit = "Restrict the stream audio level to -2dB"
+
+#twodblimit_tip = "This option may improve the audio quality at the expense of a little playback volume."
+
+#unp_controls = "Unprocessed Audio Controls"
+
 #up_arrow_tip = "This moves the highlighted track up the playlist order."
 
 #update = "Update"
 
-#update_encoder_settings_tip = "Change the encoder settings while streaming or recording. Make changes above then click this button."
+#update_encoder_settings_tip = """Use this to change the encoder settings while streaming or recording.
+# 
+#If this button is greyed out it means that the encoder is not running, or the bitrate/samplerate combination is not supported by the encoder, or you are trying to switch between Ogg and mp3, which is not permitted."""
 
 #upon_connection = "Upon connection:"
 
+#upper_vorbis = "Upper %"
+
 #use = "Use"
 
 #use_custom_srate_tip = "Complete sample rate freedom. Note that only sample rates that appear in the drop down box can be used with an mp3 stream."
 
+#use_dsp_text = "Route audio through DSP interface"
+
 #use_mp3_srate_tip = "Use one of the standard mp3 sample rates for the stream."
 
+#using_jack_server = "Using named JACK server: "
+
 #voip_mixback_volume_control_tip = "The stream volume level to send to the voice over IP connection."
 
+#vorbis_bitrate_max_tip = "The upper bitrate limit relative to the nominal bitrate. This is an advisory limit and it may be exceeded. Normally it is safe to leave the upper limit uncapped since the bitrate will be averaged and the listeners have buffers that extend for many seconds. The checkbox enables/disables this feature."
+
+#vorbis_bitrate_min_tip = "The minimum bitrate in relative percentage terms. For streaming it is recommended that you set a minimum bitrate to ensure correct listener client behaviour however setting any upper or lower limit will result in a significantly higher CPU usage by a factor of at least three, and slightly degraded sound quality. The checkbox enables/disables this feature."
+
+#vorbis_bitrate_tip = "The nominal Ogg/Vorbis bitrate in kilobits per second."
+
+#vorbis_streamtab_tip = "This chooses the Ogg/vorbis format for streaming and recording."
+
 #vorbis_tag = "Vorbis Tag"
 
-#wet_voice_player_tip = "When you click this button the jingle or track selected in the playlist will be looped continuously and will be audible during moments when the main media players are not active. The 'Stream Mon' feature needs to be turned on if the DJ wants to be able to hear it."
+#wet_voice_player_tip = "When you click this button the jingle or track selected in the playlist will be looped continuously and will be audible during moments when the main media players are not active. The 'Monitor Mix' feature needs to be set to 'Stream' if you want to be able to hear it."
 
-#wet_voice_volume_tip = "This adjusts the volume level of the music that plays whenever the other media players are not active. It is only audible to the DJ when 'Stream Mon' in the main application window is switched on."
+#wet_voice_volume_tip = "This adjusts the volume level of the music that plays whenever the other media players are not active. It is only audible to the DJ when 'Monitor Mix' in the main application window is set to 'Stream'."
 
 #window_close = "Close"
 
