@@ -28,18 +28,96 @@ add_track_tip = "Add tracks to the playlist."
 
 advance_tip = "This button either starts the currently highlighted track playing or stops the currently playing one and highlights the next track."
 
-af_h_sm = "Audio Filter, Headroom, and Stereo Mix"
+agc_compressor = "Compressor"
 
-af_mild_tip = "A moderate bass cut filter for noisy environments or boomy microphones."
+agc_controls = "Processed Audio Controls"
 
-af_off_tip = "This turns off the bass cut filter and is the normally recommended setting."
+agc_cutoff = "Cutoff Frequency"
 
-af_sharp_tip = "This bass cut filter is provided for people who have severe mains hum or an infrasound problem due to poor audio components."
+agc_deessbias = "Bias"
+
+agc_deesser = "De-esser"
+
+agc_ducker = "Ducker"
+
+agc_duckhold = "Hold"
+
+agc_duckrelease = "Release"
+
+agc_gain = "Gain"
+
+agc_hfdetail = "HF Detail"
+
+agc_hfmulti = "Effect"
+
+agc_highpass = "High Pass Filter"
+
+agc_left = "Left"
+
+agc_level = "Level"
+
+agc_lfdetail = "LF Detail"
+
+agc_lfmulti = "Effect"
+
+agc_limit = "Limit"
+
+agc_nggain = "Gain"
+
+agc_ngthresh = "Threshold"
+
+agc_noisegate = "Noise Gate"
+
+agc_other_options = "Options"
+
+agc_phaserotator = "Phase Rotator"
+
+agc_ratio = "Ratio / Boost"
+
+agc_right = "Right"
+
+agc_active_tip = "Use processed audio from this microphone channel. When selected unprocessed audio will still be used for the DJ headphones in the DJ audio mix. Activating this feature enables an audio processing pipeline whose features are explained in other tooltips below."
+
+agc_hpcutoff_tip = "Frequency in Hertz above which audio can pass to later stages. Use this feature to restrict low frequency sounds such as mains hum. Setting too high a level will make your voice sound thin."
+
+agc_hfdetail_tip = "You can use this to boost the amount of treble in the audio."
+
+agc_lfdetail_tip = "You can use this to boost the amount of bass in the audio."
+
+agc_compressor_tip = "A lookahead brick wall limiter. Use the Ratio control to boost the quieter sounds. The Limit control is used to set the absolute maximum audio level."
+
+agc_noisegate_tip = "Reduce the unwanted quietest sounds and background noise which you don't want your listeners to hear with this."
+
+agc_deesser_tip = "Reduce the S, T, and P sounds which microphones tend to exagerate. Ideally the Bias control will be set so that the de-esser is off when there is silence but is set high enough that mouse clicks are detected and suppressed."
+
+agc_ducker_tip = "The ducker automatically reduces the level of player audio when the DJ speaks. These settings allow you to adjust the timings of that audio reduction."
+
+agc_phaserotator_tip = "This feature processes the microphone audio so that it sounds more even. The effect is particularly noticable on male voices."
 
 all = "All"
 
+alternate = "Alternate"
+
 announce_tip = "Enter the message you want to send here. To include the track currently playing use %s. You can also include colours using Ctrl+K (standard X-Chat/mIRC method) or from the context menu (right click)."
 
+announcement_countdown_label = "(mm:ss)   "
+
+announcement_initial = "Create a new announcement"
+
+announcement_delete = "Modify or Delete this announcement"
+
+announcement_use = "Announcement"
+
+announcement_next_track = "Next track:"
+
+announcement_lmic = "Left Mic"
+
+announcement_rmic = "Right Mic"
+
+announcement_element = "Announcement"
+
+announcement_control_menu = "Announcement"
+
 app_exit_tip = "When IDJC exits run the commands to the right."
 
 app_start_tip = "When IDJC starts run the commands to the right."
@@ -58,7 +136,7 @@ attenuate_right_tip = "Use this to attenuate the right microphone signal so that
 
 attenuation = "Atten."
 
-audio_meters = "Audio Meters"
+audio_meters = "Meters"
 
 auto = "Auto"
 
@@ -96,6 +174,8 @@ bitrate_tip = "The bit-rate in kilobits per second."
 
 block_size = "Block size"
 
+bonus_killer = "End tracks early: those containing excessive silence."
+
 centre_pbspeed_tip = "This sets the playback speed back to normal."
 
 channels = "Channels:"
@@ -134,6 +214,12 @@ connected_to_history = "connected to"
 
 connection = " Connection "
 
+connection_lost = "Connection Lost"
+
+contact_info = " Shoutcast Contact Info "
+
+contrib_label = "Contributors"
+
 control_menu = "Insert control"
 
 copy = "Copy"
@@ -144,6 +230,10 @@ count_up = "Count Up"
 
 cross_left_tip = "Move the crossfader fully left."
 
+cross_middle_tip = "Move the crossfader to the middle of its range of travel."
+
+cross_pattern_tip = "This changes the response curve of the crossfader."
+
 cross_right_tip = "Move the crossfader fully right."
 
 crossfade_control_ltr_element = ">>> Fade across >>>"
@@ -152,10 +242,42 @@ crossfade_control_menu = "Crossfade"
 
 crossfade_control_rtl_element = "<<< Fade across <<<"
 
+crossfader = "Crossfader"
+
 crossfader_tip = "The crossfader."
 
+crosspass = "Pass"
+
 cue_up = "Cue Up"
 
+dbalbum = "Album"
+
+dbartist = "Artist"
+
+dbbitrate = "Bitrate"
+
+dbcollapse = "_Collapse"
+
+dbduration = "Duration"
+
+dbexpand = "_Expand"
+
+dbfilename = "Filename"
+
+dbfilters = " Filters "
+
+dbfuzzysearch = "Fuzzy Search"
+
+dbpath = "Path"
+
+dbtitle = "Title"
+
+dbtrack = "Track"
+
+dbunknown = "<unknown>"
+
+dbwhere = "WHERE"
+
 default_normalizer_tip = "Load the recommended settings."
 
 delete_mode_tip = "This button toggles delete mode which allows the removal of tracks from the playlist by mouse clicking them."
@@ -230,7 +352,7 @@ enable = "Enable"
 
 enable_message_timer_tip = "This widget enables the IRC message timer which broadcasts a message periodically to the specified channels."
 
-enable_stream_normalizer_tip = "This feature is provided to make the various pieces of music that are played of a more uniform loudness level which is standard practice by 'real' radio stations. The default settings are likely to be sufficient however you may adjust them and you can compare the effect by clicking the 'Stream Mon.' button in the main application window which will allow you to compare the processed with the non-processed audio."
+enable_stream_normalizer_tip = "This feature is provided to make the various pieces of music that are played of a more uniform loudness level which is standard practice by 'real' radio stations. The default settings are likely to be sufficient however you may adjust them and you can compare the effect by clicking the 'Monitor Mix' 'Stream' button in the main application window which will allow you to compare the processed with the non-processed audio."
 
 enable_tooltips = "Enable tooltips"
 
@@ -246,8 +368,22 @@ enlarge_time_elapsed_tip = "The time elapsed/remaining windows sometimes don't a
 
 event_tab = "Event"
 
+epc_title = "External Playlist"
+
+epc_active = "  Active  "
+
+epc_choosefile = "Choose a playlist file"
+
+epc_choosedirectory = "Choose a media directory"
+
 exchange = "Exchange"
 
+external = "External"
+
+external_playlist = "Choose a playlist file."
+
+external_directory = "Choose a folder/directory of music."
+
 fadeout_toggle = "Fadeout"
 
 fall = "Fall"
@@ -266,26 +402,26 @@ filter_slow = "30ms RMS"
 
 finish = "Finish"
 
-flac_bitrates = ("16 Bit", "20 Bit", "24 Bit")
-
 flac16_tip = "The ideal bit width for streaming assuming you have the bandwidth to spare."
 
 flac20_tip = "Ideal for very high quality streaming or recording although not as compatible as 16 bit."
 
 flac24_tip = "The highest quality audio format available within IDJC. Recommended for pre-recording."
 
-flacmetadata = "Metadata"
+flac_bitrates = ('16 Bit', '20 Bit', '24 Bit')
 
 flac_streamtab_tip = "This chooses the OggFLAC format for streaming and recording."
 
+flacmetadata = "Metadata"
+
 flacmetadata_tip = "You can prevent the sending of metadata by turning this feature off. This will prevent certain players from dropping the stream or inserting an audible gap every time the song title changes."
 
 format = " Format "
 
-formats = " Supported Media Formats "
-
 format_info_bar_tip = "Information about how the encoder is currently configured is displayed here."
 
+formats = " Supported Media Formats "
+
 from_here = "From Here"
 
 fully_featured = "Fully Featured"
@@ -302,7 +438,7 @@ good_quality_resample = "Good"
 
 green_phone_tip = "Mix voice over IP audio to the output stream."
 
-headroom = "Headrooom"
+headroom = "Player headroom when the microphone is open (dB)"
 
 headroom_tip = "The number of dB to reduce the music players' sound level by when the microphone is switched on. A sensible setting would be 3.0 or even higher if you are not going to use ducking."
 
@@ -316,6 +452,18 @@ Example 2: localhost"""
 
 hysteresis = "Hyster."
 
+icy_aim = "AIM:"
+
+icy_aim_tip = "Connection info for AOL instant messenger goes here."
+
+icy_icq = "ICQ:"
+
+icy_icq_tip = "ICQ instant messenger connection info goes here."
+
+icy_irc = "IRC:"
+
+icy_irc_tip = "Internet Relay Chat connection info goes here."
+
 id3_tag = "ID3 Tag"
 
 idjc_launch_failed = "IDJC Launch Failed"
@@ -326,10 +474,12 @@ initial_player_settings = "Player Settings At Startup"
 
 interval = "Interval:"
 
-invert = "Invert"
+invert_left = "Invert left mic audio"
 
 invert_left_tip = "Performs phase inversion on the left microphone signal. Use this to make both microphones be in phase with one another and to affect phase in relation to your voice with respect to the headphones."
 
+invert_right = "Invert right mic audio"
+
 invert_right_tip = "Performs phase inversion on the right microphone signal. Use this to make both microphones be in phase with one another and to affect phase in relation to your voice with respect to the headphones."
 
 irc_channels_tip = "A comma separated list of IRC channels. Some IRC servers require that you also be logged into the channel before you can announce there."
@@ -345,11 +495,11 @@ item_menu = "Item"
 jack_connection_failed = """The JACK sound server needs to be running in order to run IDJC.
 In order to manually start it try something like:
 
-\t$ jackd -d alsa -r 44100 -p 2048
+	$ jackd -d alsa -r 44100 -p 2048
 
 If you would like JACK to start automatically with your user specified parameters try something like this, which will create a file called .jackdrc in your home directory:
 
-\t$ echo "/usr/bin/jackd -d alsa -r 44100" > ~/.jackdrc
+	$ echo "/usr/bin/jackd -d alsa -r 44100" > ~/.jackdrc
 
 If you have already done this it is possible another application or non-JACK sound server is using the sound card.
 
@@ -357,8 +507,8 @@ Possible remedies would be to close the other audio app or configure the sound s
 
 If you are trying to connect to a named jack server, either set the environment variable JACK_DEFAULT_SERVER to that name or launch IDJC with the -j jackservername option. For example:
 
-\t $ jackd -n xyzzy -d alsa -r 44100 -p 2048 &
-\t $ idjc -p profilename -j xyzzy"""
+	 $ jackd -n xyzzy -d alsa -r 44100 -p 2048 &
+	 $ idjc -p profilename -j xyzzy"""
 
 jack_entry = """Enter the name of the JACK audio port with which to bind and then click the set button to the right.
 Typing 'jack_lsp -p' in a console will give you a list of valid JACK audio ports. Note that inputs will only bind to output ports and outputs will only bind to input ports."""
@@ -395,12 +545,14 @@ left_playlist_save = "Save left playlist"
 
 level = "Level"
 
-licence = "Released under the GNU General Public Licence V3.0"
+licence = "Released under the GNU General Public License V3.0"
 
-licence_window_title = "IDJC Licence Text"
+licence_tab = "Licence"
 
 listen = " Listen "
 
+listener_indicator_tip = "The combined total number of listeners some time in the last thirty seconds."
+
 listen_tip = "Make output from this player audible to the DJ."
 
 listen_url = "Listen URL:"
@@ -423,6 +575,12 @@ make_public_tip = "Publish your radio station on a listings website. The website
 
 manual = "Manual"
 
+media_flat = "Flat"
+
+media_tree = "Tree"
+
+media_viewer_title = " P3 Database View (%s) "
+
 mediafilter_all = "Supported media"
 
 message = "Message:"
@@ -437,8 +595,24 @@ metadata_checkbox_tip = "Choose the streams upon which you wish to reformat the
 
 metadata_entry_tip = "You can enter text to accompany the stream here, as well as incorporating the title of the currently playing track by including %s at the appropriate point."
 
+metadata_source_crossfader = "Crossfader"
+
+metadata_source_label = "Metadata Source"
+
+metadata_source_last_played = "Last Played"
+
+metadata_source_left_deck = "Left Deck"
+
+metadata_source_none = "None"
+
+metadata_source_right_deck = "Right Deck"
+
+metadata_source_tip = "Select which Deck is responsible for the metadata on the stream."
+
 metadata_update_tip = "Update the metadata."
 
+mic_agc = "Use AGC for mic audio processing (experimental)"
+
 mic_aux_mutex = "Make Mic and Aux buttons mutually exclusive"
 
 mic_aux_mutex_tip = "This feature ensures that the microphone and auxiliary inputs can not both be on at the same time. This allows the DJ to be able to switch between the two with only one mouse click. It may be of use to those who mix a lot of external audio, or who wish to use the auxiliary input as a secondary microphone source with different audio processing."
@@ -459,7 +633,7 @@ mic_peak_toggle = "Mic Peak"
 
 mic_peak_toggle_tip = "Controls whether to display a peak-hold signal level meter in the main application window indicating the signal strength of the individual microphone audio levels."
 
-mic_to_dj = "Microphone audio audible in headphones"
+mic_to_dj = "Send microphone audio (mono) to the DJ's headphones"
 
 mic_toggle_tip = "This button toggles the microphone input for both the left and the right microphones. To select microphones individually, right click on this button."
 
@@ -469,6 +643,8 @@ mic_vu_meter_tip = "A VU meter for the microphone audio."
 
 microphone_tab = "Microphone"
 
+middle = "Middle"
+
 mild = "Mild"
 
 mirc_colour_menu = "mIRC Colour Chart"
@@ -479,6 +655,12 @@ missing_lame = "MP3 Not available"
 
 mixer_crash = "The mixer module crashed during initialisation."
 
+monitor = "Monitor Mix"
+
+monitor_dj = "DJ"
+
+monitor_stream = "Stream"
+
 mono = "Mono"
 
 mount_point_tip = "The mount point, which is not required when dealing with Shoutcast servers. A typical mount point might be /listen or /listen.ogg. It is recommended that Ogg streams have a mount point ending in .ogg for the sake of listener client compatibility."
@@ -523,11 +705,9 @@ nick_entry_tip = "The nick specified here must match at least one of the nicks y
 
 no_more_ask = "Don't ask again"
 
-no_mp3_stream_available = ("MP3 streaming is unavailable,", "and as a consequence", "Shoutcast is also disabled.", "", "Icecast Ogg streaming only.")
+no_mp3_stream_available = ('To enable MP3 streaming', 'install the package named', "'libmp3lame'", 'and restart IDJC.')
 
-no_mp3_stream_available_tip = """Due to concerns over software patents or through oversight, the person or organisation who compiled this program neglected to include support for mp3 encoding.
- 
-In order to stream mp3 with Shoutcast you need to either locate and install an unrestricted IDJC package or failing that, compile your own from source."""
+no_mp3_stream_available_tip = """Installing libmp3lame will allow you to stream the MP3 format to Shoutcast servers. Currently only Ogg streaming to Icecast servers is possible."""
 
 no_resample = "Use JACK sample rate"
 
@@ -551,16 +731,18 @@ normrise = "Rise"
 
 off = "Off"
 
-vorbis_bitrate_max_tip = "The upper bitrate limit relative to the nominal bitrate. This is an advisory limit and it may be exceeded. Normally it is safe to leave the upper limit uncapped since the bitrate will be averaged and the listeners have buffers that extend for many seconds. The checkbox enables/disables this feature."
-
-vorbis_bitrate_min_tip = "The minimum bitrate in relative percentage terms. For streaming it is recommended that you set a minimum bitrate to ensure correct listener client behaviour however setting any upper or lower limit will result in a significantly higher CPU usage by a factor of at least three, and slightly degraded sound quality. The checkbox enables/disables this feature."
-
-vorbis_bitrate_tip = "The nominal Ogg/Vorbis bitrate in kilobits per second."
-
 ogg_streamtab_tip = "Clicking this tab selects the Ogg family of file formats."
 
 open_aux_element = "Switch to Aux input"
 
+other_mic_options = "Other Options"
+
+panning = "Stereo Panning"
+
+panning_mono = "Mono"
+
+panning_no_audio = "No Audio Source Selected"
+
 pass_button_tip = "This button causes the crossfader to move to the opposite side at a speed determined by the speed selector to the left."
 
 pass_speed_tip = "The time in seconds that the crossfader will take to automatically pass across when the button to the right is clicked."
@@ -599,24 +781,6 @@ playlist1 = "Playlist 1"
 
 playlist2 = "Playlist 2"
 
-playlistfilter_all = "All file types"
-
-playlistfilter_supported = "Playlist types (*.m3u, *.xspf, *.pls)"
-
-playlisttype_expander = "Select File Type "
-
-#playlisttype_expander_extension = "(By Extension)"
-
-#playlisttype_expander_m3u = "(M3U playlist)"
-
-#playlisttype_expander_xspf = "(XSPF playlist)"
-
-playlisttype_extension = (("By Extension", ""), ("M3U playlist", "m3u"), ("XSPF playlist", "xspf"), ("PLS playlist", "pls"))
-
-playlisttype_header1 = "File Type"
-
-playlisttype_header2 = "Extension"
-
 playlist_menu = "Playlist"
 
 playlist_modes_tip = """This sets the playlist mode which defines player behaviour after a track has finished playing.
@@ -629,7 +793,23 @@ playlist_modes_tip = """This sets the playlist mode which defines player behavio
 
 'Manual' causes the player to stop at the end of each track.
 
-'Cue Up' is similar to manual except that the next track in the playlist will also be highlighted."""
+'Cue Up' is similar to manual except that the next track in the playlist will also be highlighted.
+
+'External' draws it's tracks from an external playlist or directory one at a time. Useful for when you want to stream massive playlists.
+
+'Alternate' causes the next track to be cued up before starting the opposite player. The crossfader is moved over."""
+
+playlistfilter_all = "All file types"
+
+playlistfilter_supported = "Playlist types (*.m3u, *.xspf, *.pls)"
+
+playlisttype_expander = "Select File Type "
+
+playlisttype_extension = (('By Extension', ''), ('M3U playlist', 'm3u'), ('XSPF playlist', 'xspf'), ('PLS playlist', 'pls'))
+
+playlisttype_header1 = "File Type"
+
+playlisttype_header2 = "Extension"
 
 popupwindowplayduration = "Total play duration %s"
 
@@ -655,20 +835,50 @@ previous_tip = "Previous track."
 
 profile_already_in_use = """IDJC could not be started because the profile is currently in use by another instance of IDJC.
 
-In addition to using a different profile you also need to be running with a different JACK sound server.
- 
-Refer to the -p and -j command line options in the IDJC man page and also to the -n option for starting jackd."""
+If you wish to run more than one instance of IDJC concurrently then in addition to using a different profile you also need to be running an additional JACK sound server.
+
+For further information refer to the -p and -j command line options in the IDJC man page and also to the -n option for starting jackd."""
 
 profile_import_body = """You can choose to import settings from
 one of the existing profiles
 listed in the drop down box below."""
 
+prokyon3_connect = "Database Connect"
+
+prokyon3_database = "Database:"
+
+prokyon3_frame_text = "Prokyon3 (song title) Database"
+
+prokyon3_nosql = "Python module MySQLdb required"
+
+prokyon3_password = "Password:"
+
+prokyon3_user = "User:"
+
 question_quit = "Do you really want to quit?"
 
 r = "R"
 
 random = "Random"
 
+rdc_title = "Connection Management"
+
+rdc_delaysof = "Delays of"
+
+rdc_seconds = "seconds"
+
+rdc_visible = "Show reconnection dialog on screen"
+
+rdc_autoreconnecthas = "Auto reconnect has..."
+
+rdc_unlimited = "Unlimited retries of 5s delay"
+
+rdc_whenstreambufferfull = "When the stream buffer is full..."
+
+rdc_discard_data = "Discard data"
+
+rdc_attempt_reconnection = "Attempt reconnection"
+
 rec_directory_tip = "Choose which directory you want to save to. All file names will be in a timestamp format and have either an ogg or mp3 file extension. Important: you need to select a directory to which you have adequate write permission."
 
 rec_source_tip = "Chooses which stream to record. If the stream isn't running the encoder will be started for you. Remember to make sure the encoder settings are to your liking before you start recording."
@@ -677,6 +887,14 @@ reconnected = "IDJC Reconnected"
 
 reconnected_additional = ('Automatically reconnected to the server', 'after the server module crashed')
 
+reconnection_text_1 = "The connection to the server in tab %s has failed."
+
+reconnection_text_2 = "Automatic reconnect in %d seconds."
+
+reconnection_text_3 = "Try %d of %d."
+
+reconnection_text_3b = "Try %d."
+
 record = " Record "
 
 record_artist = "Artist:"
@@ -709,6 +927,8 @@ request_tab = "Request"
 
 resample_quality = "Quality"
 
+response = "Response"
+
 restore_session = "Restore previous session"
 
 restore_session_tip = "When starting IDJC most of the main window settings will be as they were left. As an alternative you may specify below how you want the various settings to be when IDJC starts."
@@ -779,6 +999,8 @@ set_tip = "Reroute the audio to/from the specified port"
 
 settings_warning_tip = "Adjust these settings carefully since they can have subtle but undesireable effects on the sound quality."
 
+silence_killer = "End tracks early: those that have quiet endings."
+
 sharp = "Sharp"
 
 shell_commands_tip = "Enter bash shell commands to run, separated by a semicolon for this particular event."
@@ -787,6 +1009,26 @@ song_placemarker = "Song name place marker = %s"
 
 speed_variance = "Enable the main-player speed/pitch controls"
 
+speex_complexity = "CPU"
+
+speex_complexity_tip = "This sets the level of complexity in the encoder. Higher values use more CPU but result in better sounding audio though not as great an improvement as you would get by increasing the quality setting to the left."
+
+speex_metadata_tip = "Sending metadata may cause listener clients to misbehave when the metadata changes. By keeping this feature turned off you can avoid that."
+
+speex_mode = "Mode"
+
+speex_mode_tip = "This is the audio bandwidth selector. Ultra Wide Band has a bandwidth of 16kHz; Wide Band, 8kHz; Narrow Band, 4kHz. The samplerate is twice the value of the selected bandwidth consequently all settings in the samplerate pane to the left will be disregarded apart from the resample quality setting."
+
+speex_modes = ('Ultra Wide Band', 'Wide Band', 'Narrow Band')
+
+speex_quality = "Quality"
+
+speex_quality_tip = "This picks an appropriate bitrate for the selected bandwidth on a quality metric. Q8 is a good choice for artifact-free speech and Q10 would be the ideal choice for music."
+
+speex_stereo_tip = "Apply intensity stereo to the audio stream. This is a very efficient implementation of stereo but is only really suited to voice."
+
+speex_streamtab_tip = "This chooses the Speex speech format for streaming and recording."
+
 standard_tags = "Standard Tags"
 
 start_full = "Start Full"
@@ -851,9 +1093,9 @@ stream_info = " Stream Info "
 
 stream_mic_vu = "Stream + Mic VU"
 
-stream_mon_tip = "In IDJC there are are two audio paths and this 'Stream Monitor' button toggles between them. When it is active you can hear what the listeners are hearing including the effects of the crossfader. Stream Mon needs to be off in order to make proper use of the VOIP features."
+stream_mon_tip = "In IDJC there are are two audio paths and this 'Monitor Mix' control toggles between them. When 'Stream' is active you can hear what the listeners are hearing including the effects of the crossfader. 'Monitor Mix' needs to be set to 'DJ' in order to make proper use of the VOIP features."
 
-stream_monitor = "Stream Mon."
+stream_monitor = "Monitor Stream Mix"
 
 stream_normalizer = "Stream Normaliser"
 
@@ -865,6 +1107,10 @@ stream_peak_toggle_tip = "Controls whether to display a peak-hold signal level m
 
 stream_resample = " Sample rate "
 
+stream_status_bar_toggle = "Stream Status"
+
+stream_status_tip = "Controls whether to display a stream status meter in the main window."
+
 stream_tab_tip = "Each one of these tabs represents a separate radio streamer. The LED indicator colours represent the following: Clear=No connection Yellow=Awaiting authentication. Green=Connected. Flashing=Packet loss due to a bad connection."
 
 stream_tip = "Make output from this player available for streaming."
@@ -873,6 +1119,10 @@ stream_vu_meter_tip = "A VU meter for the stream audio."
 
 streamer_resample_quality = "This selects the audio resampling method to be used, efficiency versus quality. Highest mode offers the best sound quality but also uses the most CPU (not recommended for systems built before 2006). Fastest mode while it uses by far the least amount of CPU should be avoided if at all possible."
 
+streams = "Streams"
+
+streams_tip = "This indicates the state of the various streams. Flashing means stream packets are being discarded because of network congestion. Partial red means the send buffer is partially full indicating difficulty communicating with the server. Green means everything is okay."
+
 tag_album = "Album:"
 
 tag_artist = "Artist:"
@@ -897,6 +1147,8 @@ this = "This"
 
 threshold = "Thresh."
 
+time = "Time"
+
 timed_out = ('Automatically disconnected from the server,', 'after the connection timed out.')
 
 to_here = "To Here"
@@ -921,8 +1173,24 @@ transfer_control_rtl_element = "<<< Transfer across <<<"
 
 translationcopyright = "Copyright (C) 2008 Stephen Fairchild (s-fairchild@users.sourceforge.net)"
 
+try_now = "Try Now"
+
+twodblimit = "Restrict the stream audio level to -2dB"
+
+twodblimit_tip = "This option may improve the audio quality at the expense of a little playback volume."
+
 unexpected = "A connection to a radio server failed."
 
+unp_controls = "Unprocessed Audio Controls"
+
+unp_left = "Left"
+
+unp_right = "Right"
+
+unp_gain = "Gain"
+
+unp_gain_tip = "This controls the level of unprocessed audio and when processed audio is selected, the level of microphone audio for the DJ mix."
+
 up_arrow_tip = "This moves the highlighted track up the playlist order."
 
 update = "Update"
@@ -937,23 +1205,31 @@ upper_vorbis = "Upper %"
 
 use = "Use"
 
-using_jack_server = "Using named JACK server: "
-
 use_custom_srate_tip = "Complete sample rate freedom. Note that only sample rates that appear in the drop down box can be used with an mp3 stream."
 
+use_dsp_text = "Route audio through DSP interface"
+
 use_jack_srate_tip = "No additional resampling will occur. The stream sample rate will be that of the JACK sound server."
 
 use_mp3_srate_tip = "Use one of the standard mp3 sample rates for the stream."
 
+using_jack_server = "Using named JACK server: "
+
 voip_mixback_volume_control_tip = "The stream volume level to send to the voice over IP connection."
 
+vorbis_bitrate_max_tip = "The upper bitrate limit relative to the nominal bitrate. This is an advisory limit and it may be exceeded. Normally it is safe to leave the upper limit uncapped since the bitrate will be averaged and the listeners have buffers that extend for many seconds. The checkbox enables/disables this feature."
+
+vorbis_bitrate_min_tip = "The minimum bitrate in relative percentage terms. For streaming it is recommended that you set a minimum bitrate to ensure correct listener client behaviour however setting any upper or lower limit will result in a significantly higher CPU usage by a factor of at least three, and slightly degraded sound quality. The checkbox enables/disables this feature."
+
+vorbis_bitrate_tip = "The nominal Ogg/Vorbis bitrate in kilobits per second."
+
 vorbis_streamtab_tip = "This chooses the Ogg/vorbis format for streaming and recording."
 
 vorbis_tag = "Vorbis Tag"
 
-wet_voice_player_tip = "When you click this button the jingle or track selected in the playlist will be looped continuously and will be audible during moments when the main media players are not active. The 'Stream Mon' feature needs to be turned on if the DJ wants to be able to hear it."
+wet_voice_player_tip = "When you click this button the jingle or track selected in the playlist will be looped continuously and will be audible during moments when the main media players are not active. The 'Monitor Mix' feature needs to be set to 'Stream' if you want to be able to hear it."
 
-wet_voice_volume_tip = "This adjusts the volume level of the music that plays whenever the other media players are not active. It is only audible to the DJ when 'Stream Mon' in the main application window is switched on."
+wet_voice_volume_tip = "This adjusts the volume level of the music that plays whenever the other media players are not active. It is only audible to the DJ when 'Monitor Mix' in the main application window is set to 'Stream'."
 
 window_close = "Close"
 
