@@ -23,7 +23,8 @@ pygtk.require('2.0')
 import gtk
 import gobject
 
-import os, time, fcntl
+import os, time, fcntl, subprocess, urllib2
+import xml.dom.minidom as mdom
 
 from idjc_config import *
 from ln_text import ln
@@ -508,9 +509,9 @@ class StreamTab(Tab):
                self.recorder_valid_override = sens = self.vorbis_settings_valid
             elif self.subformat_page == 1:   # OggFLAC
                sr = self.stream_resample_frame.resample_rate
-               sens = sr <= 65535 or sr % 10 == 0
+               self.recorder_valid_override = sens = sr <= 65535 or sr % 10 == 0
             elif self.subformat_page == 2:   # Speex
-               sens = True                   # True always for now
+               self.recorder_valid_override = sens = True                   # True always for now
             self.server_connect.set_sensitive(sens and non_shoutcast or self.server_connect.get_active())
             self.test_monitor.set_sensitive(sens)
          elif self.format_page == 2:
@@ -634,6 +635,9 @@ class StreamTab(Tab):
                                   "listen_url=" + self.listen_url_entry.get_text().strip(),
                                   "description=" + self.description_entry.get_text().strip(),
                                   "genre=" + self.genre_entry.get_text().strip(),
+                                  "irc=" + self.irc_entry.get_text().strip(),
+                                  "aim=" + self.aim_entry.get_text().strip(),
+                                  "icq=" + self.icq_entry.get_text().strip(),
                                   "make_public=" + str(bool(self.make_public.get_active())),
                                   "command=server_connect\n"))
          self.send(self.connection_string)
@@ -641,11 +645,24 @@ class StreamTab(Tab):
          if self.receive() == "failed":
             self.server_connect.set_active(False)
             self.connection_string = None
+         else:
+            if self.is_shoutcast:
+               self.stats_url = "http://%s:%d/admin.cgi?mode=viewxml" % (self.host_entry.get_text(), self.port_adj.get_value())
+               auth = urllib2.HTTPBasicAuthHandler()
+               auth.add_password(realm="Shoutcast Server", uri="https://%s:%d" % (self.host_entry.get_text(), self.port_adj.get_value()), user="admin", passwd=self.passwd_entry.get_text())
+            else:
+               self.stats_url = "http://%s:%d/admin/listclients?mount=%s" % (self.host_entry.get_text(), self.port_adj.get_value(), self.mount_entry.get_text())
+               auth_url = "https" + self.stats_url[4:]
+               auth = urllib2.HTTPBasicAuthHandler()
+               auth.add_password(realm="Icecast2 Server", uri=auth_url, user=self.login_entry.get_text(), passwd=self.passwd_entry.get_text())
+            opener = urllib2.build_opener(auth)
+            urllib2.install_opener(opener)
       else:
          self.send("command=server_disconnect\n")
          self.receive()
          self.start_stop_encoder(ENCODER_STOP)
          self.connection_string = None
+         self.stats_url = None
    def cb_test_monitor(self, widget):
       if widget.get_active():
          self.start_stop_encoder(ENCODER_START)
@@ -709,7 +726,14 @@ class StreamTab(Tab):
             else:
                self.format_info_bar.push(1, "")
          elif self.subformat_page == 2: # speex
-            pass
+            speex_srate = (32000, 16000, 8000)[self.speex_mode.get_active()]
+            speex_channels = ("mono", "stereo")[self.speex_stereo.get_active()]
+            self.send("format=ogg\nsubformat=speex\nencode_source=jack\nsample_rate=%d\nresample_quality=%s\nspeex_mode=%d\nstereo=%s\nuse_metadata=%d\nspeex_quality=%s\nspeex_complexity=%s\ncommand=%s\n" % (speex_srate, self.stream_resample_frame.resample_quality, self.speex_mode.get_active(), speex_channels, self.speex_metadata.get_active(), self.speex_quality.get_active_text(), self.speex_complexity.get_active_text(), command))
+            metatext = ("-Meta", "+Meta")[self.speex_metadata.get_active()]
+            if self.receive() == "succeeded":
+               self.format_info_bar.push(1, "Speex   %s   %s   Q%s   C%s   %s" % (self.speex_mode.get_active_text(), speex_channels.capitalize(), self.speex_quality.get_active_text(), self.speex_complexity.get_active_text(), metatext))
+            else:
+               self.format_info_bar.push(1, "")
       else:
          if self.file_dialog.get_filename().endswith(".mp3"):
             self.encoder = "mp3"
@@ -743,6 +767,8 @@ class StreamTab(Tab):
       self.encoder_on_count = 0			# when this counter hits zero the encoder is turned off
       self.format_page = 0			# the current format page
       self.subformat_page = 0                   # the Ogg sub-format
+      self.stats_url = None
+      self.currentlisteners = 0
       Tab.set_spacing(self, 10)
       scrolled = gtk.ScrolledWindow()
       Tab.add(self, scrolled)
@@ -775,7 +801,7 @@ class StreamTab(Tab):
       self.host_entry = gtk.Entry()
       self.host_entry.set_text("localhost")
       set_tip(self.host_entry, ln.hostname_tip)
-      self.port_adj = gtk.Adjustment(8000, 0, 65535, 1, 1, 1)
+      self.port_adj = gtk.Adjustment(8000, 0, 65535, 1, 1)
       self.port_spinbox = gtk.SpinButton(self.port_adj, 0.4, 0)
       set_tip(self.port_spinbox, ln.port_tip)
       self.mount_entry = gtk.Entry()
@@ -829,7 +855,7 @@ class StreamTab(Tab):
       self.format_notebook.show()
       
       # mp3 tab
-      self.mp3tab = self.make_notebook_tab(self.format_notebook, "mp3", ln.mp3_streamtab_tip)
+      self.mp3tab = self.make_notebook_tab(self.format_notebook, "MP3", ln.mp3_streamtab_tip)
       self.standard_mp3_bitrate, self.custom_mp3_bitrate = self.make_radio(2)
       set_tip(self.standard_mp3_bitrate, ln.std_mp3_rate_tip)
       set_tip(self.custom_mp3_bitrate, ln.nonstd_mp3_rate_tip)
@@ -888,9 +914,10 @@ class StreamTab(Tab):
       self.subformat_notebook.show()
       self.oggvorbistab = self.make_notebook_tab(self.subformat_notebook, "Vorbis", ln.vorbis_streamtab_tip)
       self.oggflactab = self.make_notebook_tab(self.subformat_notebook, "FLAC", ln.flac_streamtab_tip)
+      self.oggspeextab = self.make_notebook_tab(self.subformat_notebook, "Speex", ln.speex_streamtab_tip)
       
       # Vorbis subtab contents
-      self.vorbis_encoding_nominal_spin_adj = gtk.Adjustment(128, 45, 500, 1, 10, 0)
+      self.vorbis_encoding_nominal_spin_adj = gtk.Adjustment(128, 8, 500, 1, 10, 0)
       self.vorbis_encoding_nominal_spin_control = SimpleFramedSpin(ln.bitrate, self.vorbis_encoding_nominal_spin_adj)
       self.vorbis_encoding_nominal_spin_control.spin.connect("value-changed", self.cb_vorbistab)
       
@@ -948,6 +975,66 @@ class StreamTab(Tab):
       self.oggflactab.add(flac_pane)
       flac_pane.show_all()
       
+      # Speex subtab contents
+      self.speex_mode = gtk.combo_box_new_text()
+      for each in ln.speex_modes:
+         self.speex_mode.append_text(each)
+      self.speex_mode.set_active(0)
+      self.speex_stereo = gtk.CheckButton(ln.stereo)
+      set_tip(self.speex_stereo, ln.speex_stereo_tip)
+      self.speex_metadata = gtk.CheckButton(ln.flacmetadata)
+      set_tip(self.speex_metadata, ln.speex_metadata_tip)
+      self.speex_quality = gtk.combo_box_new_text()
+      for i in range(11):
+         self.speex_quality.append_text("%d" % i)
+      self.speex_quality.set_active(8)
+      self.speex_complexity = gtk.combo_box_new_text()
+      for i in range(1, 11):
+         self.speex_complexity.append_text("%d" % i)
+      self.speex_complexity.set_active(2)
+      
+      if speexenabled:
+         svbox = gtk.VBox()
+         svbox.set_border_width(5)
+         
+         label = gtk.Label(ln.speex_mode)
+         shbox0 = gtk.HBox()
+         shbox0.set_spacing(5)
+         shbox0.pack_start(label, False, False, 0)
+         shbox0.pack_start(self.speex_mode, True, True, 0)
+         set_tip(shbox0, ln.speex_mode_tip)
+         svbox.pack_start(shbox0, True, False, 0)
+         shbox1 = gtk.HBox()
+         shbox1.pack_start(self.speex_stereo, True, False, 0)
+         shbox1.pack_end(self.speex_metadata, True, False, 0)
+         svbox.pack_start(shbox1, True, False, 0)
+         shbox2 = gtk.HBox()
+         shbox3 = gtk.HBox()
+         shbox3.set_spacing(5)
+         shbox4 = gtk.HBox()
+         shbox4.set_spacing(5)
+         shbox2.pack_start(shbox3, False, False, 0)
+         shbox2.pack_end(shbox4, False, False, 0)
+         
+         label = gtk.Label(ln.speex_quality)
+         shbox3.pack_start(label, False, False, 0)
+         shbox3.pack_start(self.speex_quality, False, False, 0)
+         set_tip(shbox3, ln.speex_quality_tip)
+         
+         label = gtk.Label(ln.speex_complexity)
+         shbox4.pack_start(label, False, False, 0)
+         shbox4.pack_start(self.speex_complexity, False, False, 0)
+         set_tip(shbox4, ln.speex_complexity_tip)
+         
+         svbox.pack_start(shbox2, True, False, 0)
+         self.oggspeextab.add(svbox)
+         svbox.show_all()
+      else:
+         label = gtk.Label(ln.feature_disabled)
+         self.oggspeextab.add(label)
+         label.show()
+      
+      # File tab contents
       self.filetab = self.make_notebook_tab(self.format_notebook, "File")	# File tab
       filefilter = gtk.FileFilter()
       filefilter.add_pattern("*.[mM]p3")
@@ -1028,10 +1115,32 @@ class StreamTab(Tab):
       stream_details_pane = self.label_item_layout(((ln.dj_name, self.dj_name_entry),
       					      (ln.listen_url, self.listen_url_entry),
                                               (ln.description, self.description_entry),
-                                              (ln.genre, genre_entry_box)), info_sizegroup)
+                                              (ln.genre, genre_entry_box)
+                                              ), info_sizegroup)
       stream_details_pane.set_border_width(10)
       frame.add(stream_details_pane)
       stream_details_pane.show()
+      
+      frame = ModuleFrame(ln.contact_info)	# contact information
+      if enh_libshout:
+         scrolled_vbox.pack_start(frame, False, False, 0)
+         frame.show()
+      self.irc_entry = gtk.Entry()
+      set_tip(self.irc_entry, ln.icy_irc_tip)
+      self.aim_entry = gtk.Entry()
+      set_tip(self.aim_entry, ln.icy_aim_tip)
+      self.icq_entry = gtk.Entry()
+      set_tip(self.icq_entry, ln.icy_icq_tip)
+      contact_sizegroup = gtk.SizeGroup(gtk.SIZE_GROUP_VERTICAL)
+      contact_details_pane = self.label_item_layout((
+                                              (ln.icy_irc, self.irc_entry),
+                                              (ln.icy_aim, self.aim_entry),
+                                              (ln.icy_icq, self.icq_entry)
+                                              ), contact_sizegroup)
+      contact_details_pane.set_border_width(10)
+      frame.add(contact_details_pane)
+      contact_details_pane.show()
+      
       hbox = gtk.HBox()					# box containing connect button and timers
       hbox.set_spacing(30)
       self.server_connect = gtk.ToggleButton(ln.server_connect)
@@ -1108,6 +1217,11 @@ class StreamTab(Tab):
                         "flac_metadata": (self.flacmetadata, "active"),
                         "flac_20_bit": (self.flac20bit, "active"),
                         "flac_24_bit": (self.flac24bit, "active"),
+                        "speex_mode": (self.speex_mode, "active"),
+                        "speex_stereo": (self.speex_stereo, "active"), 
+                        "speex_metadata": (self.speex_metadata, "active"), 
+                        "speex_quality": (self.speex_quality, "active"),
+                        "speex_complexity": (self.speex_complexity, "active"),
                         "file_source" : (self.file_dialog, "filename"),
                         "file_use_offset" : (self.file_offset_checkbutton, "active"),
                         "file_offset" : (self.file_offset_adj, "value"),
@@ -1116,6 +1230,9 @@ class StreamTab(Tab):
                         "description" : (self.description_entry, "text"),
                         "genre" : (self.genre_entry, "text"),
                         "make_public" : (self.make_public, "active"),
+                        "contact_aim" : (self.aim_entry, "text"),
+                        "contact_irc" : (self.irc_entry, "text"),
+                        "contact_icq" : (self.icq_entry, "text"),
                         "timer_start_active" : (self.start_timer.check, "active"),
                         "timer_start_time" : (self.start_timer.entry, "text"),
                         "timer_stop_active" : (self.stop_timer.check, "active"),
@@ -1124,6 +1241,7 @@ class StreamTab(Tab):
                         "action_play_which" : (self.start_player_action, "radioindex"),
                         "action_record_active" : (self.start_recorder_action, "active"),
                         "action_record_which" : (self.start_recorder_action, "radioindex") }
+      self.reconnection_dialog = ReconnectionDialog(self)
 
 class RecordTab(Tab):
    class RecordButtons(CategoryFrame):
@@ -1318,7 +1436,63 @@ class TabFrame(ModuleFrame):
 class SourceClientGui:
    server_errmsg = "idjc: the server module appears to have crashed -- possible segfault"
    unexpected_reply = "unexpected reply from idjcsourceclient"
+   def get_stats(self, streamtab):
+      """recover the listener stats from the server
+      note that this runs asynchronously"""
+      class BadXML(ValueError):
+         pass
+      
+      req = urllib2.Request(streamtab.stats_url)
+      req.add_header("User-agent", "Mozilla/5.0")
+      try:
+         f = urllib2.urlopen(req)
+         xmlfeed = f.read()
+      except:
+         print "failed to get server stats for tab", streamtab.numeric_id + 1
+         return
+      f.close()
+      try:
+         dom = mdom.parseString(xmlfeed)
+      except:
+         print "failed to parse server stats for tab", streamtab.numeric_id + 1
+         return
+      
+      try:
+         if streamtab.is_shoutcast:
+            if dom.documentElement.tagName == u'SHOUTCASTSERVER':
+               shoutcastserver = dom.documentElement
+            else:
+               raise BadXML
+            currentlisteners = shoutcastserver.getElementsByTagName('CURRENTLISTENERS')
+            try:
+               streamtab.currentlisteners = int(currentlisteners[0].firstChild.wholeText.strip())
+            except:
+               raise BadXML
+         else:
+            if dom.documentElement.tagName == u'icestats':
+               icestats = dom.documentElement
+            else:
+               raise BadXML
+            sources = icestats.getElementsByTagName('source')
+            for source in sources:
+               mount = source.getAttribute('mount')
+               if streamtab.stats_url.endswith(mount):
+                  listeners = source.getElementsByTagName('Listeners')
+                  try:
+                     streamtab.currentlisteners = int(listeners[0].firstChild.wholeText.strip())
+                     break
+                  except:
+                     raise BadXML
+            else:
+               raise BadXML
+      except BadXML:
+         print "Unexpected data in server stats XML file"
+         streamtab.currentlisteners = 0
+      dom.unlink()
+      print "server", streamtab.numeric_id + 1, "has", streamtab.currentlisteners, "listeners"
+
    def monitor(self):
+      self.monitor_count += 1
       self.led_alternate = not self.led_alternate
       streaming = recording = False
       gtk.gdk.threads_enter()
@@ -1335,7 +1509,16 @@ class SourceClientGui:
                rectab.time_indicator.set_value(int(recorded_seconds))
                if recorder_state != "0":
                   recording = True
+      listeners = 0
       for streamtab in self.streamtabframe.tabs:
+         monitor_phase = self.monitor_count & 63
+         if monitor_phase == 0:
+            if streamtab.stats_url is not None:
+               gobject.idle_add(self.get_stats, streamtab)
+            else:
+               streamtab.currentlisteners = 0
+         if monitor_phase == 63:
+            listeners += streamtab.currentlisteners
          self.send("dev_type=streamer\ntab_id=%d\ncommand=get_report\n" % streamtab.numeric_id)
          reply = self.receive()
          if reply != "failed":
@@ -1343,17 +1526,33 @@ class SourceClientGui:
             if reply.startswith("streamer%dreport=" % streamtab.numeric_id):
                streamer_state, stream_sendbuffer_pc, brand_new = reply.split("=")[1].split(":")
                streamtab.show_indicator(("clear", "amber", "green", "clear")[int(streamer_state)])
-               if (streamer_state == "2" and int(stream_sendbuffer_pc) >= 100 and self.led_alternate):
-                  streamtab.show_indicator("amber")
+               mi = self.parent.stream_indicator[streamtab.numeric_id]
+               if (streamer_state == "2"):
+                  mi.set_active(True)
+                  mi.set_value(int(stream_sendbuffer_pc))
+                  if int(stream_sendbuffer_pc) >= 100 and self.led_alternate:
+                     if self.parent.prefs_window.recon_config.discard_data.get_active():
+                        streamtab.show_indicator("amber")
+                        mi.set_flash(True)
+                     else:
+                        streamtab.server_connect.set_active(False)
+                        streamtab.server_connect.set_active(True)
+                        print "remade the connection because stream buffer was full"
+                  else:
+                     mi.set_flash(False)
+               else:
+                  mi.set_active(False)
+                  mi.set_flash(False)
                if brand_new == "1":
                   # connection has just been made, do user requested actions at this time
                   streamtab.start_recorder_action.activate()
                   streamtab.start_player_action.activate()
+                  streamtab.reconnection_dialog.deactivate()
                if streamer_state != "0":
                   streaming = True
                elif streamtab.server_connect.get_active():
                   streamtab.server_connect.set_active(False)
-                  self.disconnected_dialog.present()
+                  streamtab.reconnection_dialog.activate()
             else:
                print "sourceclientgui.monitor: bad reply for streamer data:", reply
          else:
@@ -1373,6 +1572,7 @@ class SourceClientGui:
                self.autoshutdown_dialog.present()
          self.is_streaming = streaming
          self.is_recording = recording
+         streamtab.reconnection_dialog.run()
       if streaming and self.parent.prefs_window.timer_enable.get_active() and (self.last_message_time + (self.parent.prefs_window.intervaladj.get_value() * 60) < time.time()):
          pw = self.parent.prefs_window
          self.last_message_time = time.time()
@@ -1389,6 +1589,8 @@ class SourceClientGui:
             file.close()
          except IOError:
             print "Problem writing the timer file to disk"
+      if monitor_phase == 63:
+         self.parent.listener_indicator.set_text(str(listeners))
       gtk.gdk.threads_leave()
       return True
    def stop_streaming_all(self):
@@ -1460,41 +1662,56 @@ class SourceClientGui:
       if self.receive() == "succeeded":
          print "updated metadata successfully" 
    def source_client_open(self):
-      self.comms_cmd, self.comms_rply = os.popen2([libexecdir + "idjcsourceclient"], 4096)
+      try:
+         sp_sc = subprocess.Popen([libexecdir + "idjcsourceclient"], bufsize = 4096, stdin = subprocess.PIPE, stdout = subprocess.PIPE, close_fds = True)
+      except Exception, inst:
+         print inst
+         print "unable to open a pipe to the sourceclient module"
+	 self.app_exit()
+      (self.comms_cmd, self.comms_rply) = (sp_sc.stdin, sp_sc.stdout)
       self.comms_reply_pending = True
       reply = self.receive()
       if reply != "succeeded":
          print self.server_errmsg
          self.app_exit()
+      self.send("encoders=%d\nstreamers=%d\nrecorders=%d\ncommand=threads_init\n" % (num_encoders, num_streamers, num_recorders))
+      if self.receive() != "succeeded":
+         print self.unexpected_reply
+         print "failed to initialise threads\n"
+         self.app_exit()
+      self.send("command=jack_samplerate_request\n")
+      reply = self.receive()
+      if reply != "failed" and self.receive() == "succeeded":
+         sample_rate_string = reply
       else:
-         self.send("encoders=%d\nstreamers=%d\nrecorders=%d\ncommand=threads_init\n" % (num_encoders, num_streamers, num_recorders))
-         if self.receive() != "succeeded":
-            print self.unexpected_reply
-            print "failed to initialise threads\n"
-            self.app_exit()
-         self.send("command=jack_samplerate_request\n")
-         reply = self.receive()
-         if reply != "failed" and self.receive() == "succeeded":
-            sample_rate_string = reply
+         print self.unexpected_reply
+         print "failed to obtain the sample rate"
+         self.app_exit()
+      if not sample_rate_string.startswith("sample_rate="):
+         print self.unexpected_reply
+         print "sample rate reply contains the following:", sample_rate_string
+         self.app_exit()
+      self.send("command=encoder_lame_availability\n")
+      reply = self.receive()
+      if reply != "failed" and self.receive() == "succeeded" and reply.startswith("lame_available="):
+         global lameenabled
+         if reply[15] == "1":
+            lameenabled = 1
          else:
-            print self.unexpected_reply
-            print "failed to obtain the sample rate"
-            self.app_exit()
-         if not sample_rate_string.startswith("sample_rate="):
-            print self.unexpected_reply
-            print "sample rate reply contains the following:", sample_rate_string
-            self.app_exit()
-         else:
-            print "threads initialised"
-            self.jack_sample_rate = int(sample_rate_string[12:])
-            print "jack sample rate is", self.jack_sample_rate
-            try:
-               for streamtab in self.streamtabframe.tabs:
-                  streamtab.stream_resample_frame.jack_sample_rate = self.jack_sample_rate
-                  streamtab.stream_resample_frame.resample_dummy_object.clicked()
-                  # update the stream tabs with the current jack sample rate
-            except (NameError, AttributeError):
-               pass	# stream tabs will not have been created yet and no further action is needed
+            lameenabled = 0
+      else:
+         print self.unexpected_reply
+         self.app_exit()
+      print "threads initialised"
+      self.jack_sample_rate = int(sample_rate_string[12:])
+      print "jack sample rate is", self.jack_sample_rate
+      try:
+         for streamtab in self.streamtabframe.tabs:
+            streamtab.stream_resample_frame.jack_sample_rate = self.jack_sample_rate
+            streamtab.stream_resample_frame.resample_dummy_object.clicked()
+            # update the stream tabs with the current jack sample rate
+      except (NameError, AttributeError):
+         pass	# stream tabs will not have been created yet and no further action is needed
    def source_client_close(self):
       try:
          self.comms_cmd
@@ -1693,5 +1910,7 @@ class SourceClientGui:
 
       self.autoshutdown_dialog = error_notification_dialog(self.dialog_group, self.parent.window_group, ln.disconnected, ln.autoshutdown)
       
+      self.monitor_count = 0
+      
       self.monitor_source_id = gobject.timeout_add(250, self.monitor)
       self.window.realize()   # prevent rendering bug and problems with sizegroups on certain widgets
